from typing import Any

import proto

__protobuf__: Any

class CustomerPayPerConversionEligibilityFailureReasonEnum(proto.Message):
    class CustomerPayPerConversionEligibilityFailureReason(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NOT_ENOUGH_CONVERSIONS: int
        CONVERSION_LAG_TOO_HIGH: int
        HAS_CAMPAIGN_WITH_SHARED_BUDGET: int
        HAS_UPLOAD_CLICKS_CONVERSION: int
        AVERAGE_DAILY_SPEND_TOO_HIGH: int
        ANALYSIS_NOT_COMPLETE: int
        OTHER: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import criteria as criteria

__protobuf__: Any

class CampaignBidModifier(proto.Message):
    resource_name: Any
    campaign: Any
    criterion_id: Any
    bid_modifier: Any
    interaction_type: Any



from .base import (
    SmartCampaignSearchTermViewServiceTransport as SmartCampaignSearchTermViewServiceTransport,
)
from .grpc import (
    SmartCampaignSearchTermViewServiceGrpcTransport as SmartCampaignSearchTermViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class UploadClickConversionsRequest(proto.Message):
    customer_id: Any
    conversions: Any
    partial_failure: Any
    validate_only: Any

class UploadClickConversionsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class UploadCallConversionsRequest(proto.Message):
    customer_id: Any
    conversions: Any
    partial_failure: Any
    validate_only: Any

class UploadCallConversionsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class ClickConversion(proto.Message):
    gclid: Any
    conversion_action: Any
    conversion_date_time: Any
    conversion_value: Any
    currency_code: Any
    order_id: Any
    external_attribution_data: Any
    custom_variables: Any

class CallConversion(proto.Message):
    caller_id: Any
    call_start_date_time: Any
    conversion_action: Any
    conversion_date_time: Any
    conversion_value: Any
    currency_code: Any
    custom_variables: Any

class ExternalAttributionData(proto.Message):
    external_attribution_credit: Any
    external_attribution_model: Any

class ClickConversionResult(proto.Message):
    gclid: Any
    conversion_action: Any
    conversion_date_time: Any

class CallConversionResult(proto.Message):
    caller_id: Any
    call_start_date_time: Any
    conversion_action: Any
    conversion_date_time: Any

class CustomVariable(proto.Message):
    conversion_custom_variable: Any
    value: Any



from typing import Any

import proto

__protobuf__: Any

class GeoTargetConstantSuggestionErrorEnum(proto.Message):
    class GeoTargetConstantSuggestionError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LOCATION_NAME_SIZE_LIMIT: int
        LOCATION_NAME_LIMIT: int
        INVALID_COUNTRY_CODE: int
        REQUEST_PARAMETERS_UNSET: int



from typing import Any

import proto

__protobuf__: Any

class UserListNumberRuleItemOperatorEnum(proto.Message):
    class UserListNumberRuleItemOperator(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        GREATER_THAN: int
        GREATER_THAN_OR_EQUAL: int
        EQUALS: int
        NOT_EQUALS: int
        LESS_THAN: int
        LESS_THAN_OR_EQUAL: int



from typing import Any

import proto

__protobuf__: Any

class GetCustomerFeedRequest(proto.Message):
    resource_name: Any

class MutateCustomerFeedsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any
    response_content_type: Any

class CustomerFeedOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any
    remove: Any

class MutateCustomerFeedsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateCustomerFeedResult(proto.Message):
    resource_name: Any
    customer_feed: Any



import logging
from typing import Callable, Optional, TypeVar

import grpc

from google.ads.googleads import v7, v8

from .interceptor import Interceptor

_Request = TypeVar(
    "_Request",
    v7.SearchGoogleAdsRequest,
    v7.SearchGoogleAdsStreamRequest,
    v8.SearchGoogleAdsRequest,
    v8.SearchGoogleAdsStreamRequest,
)
_Response = TypeVar("_Response")

class LoggingInterceptor(
    Interceptor, grpc.UnaryUnaryClientInterceptor, grpc.UnaryStreamClientInterceptor
):
    endpoint: str = ...
    logger: logging.Logger = ...
    def __init__(
        self, logger: logging.Logger, api_version: str, endpoint: Optional[str] = ...
    ) -> None: ...
    def intercept_unary_unary(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...
    def intercept_unary_stream(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...



from typing import Any

import proto

__protobuf__: Any

class ResponseContentTypeEnum(proto.Message):
    class ResponseContentType(proto.Enum):
        UNSPECIFIED: int
        RESOURCE_NAME_ONLY: int
        MUTABLE_RESOURCE: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    manager_link_status as manager_link_status,
)

__protobuf__: Any

class CustomerClientLink(proto.Message):
    resource_name: Any
    client_customer: Any
    manager_link_id: Any
    status: Any
    hidden: Any



from typing import Any

import proto

__protobuf__: Any

class AccountBudgetProposalTypeEnum(proto.Message):
    class AccountBudgetProposalType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CREATE: int
        UPDATE: int
        END: int
        REMOVE: int



from typing import Any

import proto

__protobuf__: Any

class ValueRuleDeviceTypeEnum(proto.Message):
    class ValueRuleDeviceType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MOBILE: int
        DESKTOP: int
        TABLET: int



from .base import (
    DynamicSearchAdsSearchTermViewServiceTransport as DynamicSearchAdsSearchTermViewServiceTransport,
)
from .grpc import (
    DynamicSearchAdsSearchTermViewServiceGrpcTransport as DynamicSearchAdsSearchTermViewServiceGrpcTransport,
)



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2
from google.rpc import status_pb2 as status_pb2

from google.ads.googleads.v8.resources.types import (
    keyword_plan_campaign as keyword_plan_campaign,
)

__protobuf__: Any

class GetKeywordPlanCampaignRequest(proto.Message):
    resource_name: Any

class MutateKeywordPlanCampaignsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any

class KeywordPlanCampaignOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any
    remove: Any

class MutateKeywordPlanCampaignsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateKeywordPlanCampaignResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class CallConversionReportingStateEnum(proto.Message):
    class CallConversionReportingState(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DISABLED: int
        USE_ACCOUNT_LEVEL_CALL_CONVERSION_ACTION: int
        USE_RESOURCE_LEVEL_CALL_CONVERSION_ACTION: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    account_link_status as account_link_status,
    linked_account_type as linked_account_type,
    mobile_app_vendor as mobile_app_vendor,
)

__protobuf__: Any

class AccountLink(proto.Message):
    resource_name: Any
    account_link_id: Any
    status: Any
    type_: Any
    third_party_app_analytics: Any
    data_partner: Any
    google_ads: Any

class ThirdPartyAppAnalyticsLinkIdentifier(proto.Message):
    app_analytics_provider_id: Any
    app_id: Any
    app_vendor: Any

class DataPartnerLinkIdentifier(proto.Message):
    data_partner_id: Any

class GoogleAdsLinkIdentifier(proto.Message):
    customer: Any



from typing import Any

import proto

__protobuf__: Any

class AdServingOptimizationStatusEnum(proto.Message):
    class AdServingOptimizationStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        OPTIMIZE: int
        CONVERSION_OPTIMIZE: int
        ROTATE: int
        ROTATE_INDEFINITELY: int
        UNAVAILABLE: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    asset_field_type as asset_field_type,
    asset_link_status as asset_link_status,
)

__protobuf__: Any

class AdGroupAsset(proto.Message):
    resource_name: Any
    ad_group: Any
    asset: Any
    field_type: Any
    status: Any



from typing import Any

import proto

from google.ads.googleads.v7.common.types import offline_user_data as offline_user_data
from google.ads.googleads.v7.resources.types import (
    offline_user_data_job as offline_user_data_job,
)

__protobuf__: Any

class CreateOfflineUserDataJobRequest(proto.Message):
    customer_id: Any
    job: Any
    validate_only: Any

class CreateOfflineUserDataJobResponse(proto.Message):
    resource_name: Any

class GetOfflineUserDataJobRequest(proto.Message):
    resource_name: Any

class RunOfflineUserDataJobRequest(proto.Message):
    resource_name: Any
    validate_only: Any

class AddOfflineUserDataJobOperationsRequest(proto.Message):
    resource_name: Any
    enable_partial_failure: Any
    operations: Any
    validate_only: Any

class OfflineUserDataJobOperation(proto.Message):
    create: Any
    remove: Any
    remove_all: Any

class AddOfflineUserDataJobOperationsResponse(proto.Message):
    partial_failure_error: Any



from typing import Any

import proto

__protobuf__: Any

class GoogleVoiceCallStatusEnum(proto.Message):
    class GoogleVoiceCallStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MISSED: int
        RECEIVED: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    account_budget_proposal_status as account_budget_proposal_status,
    account_budget_proposal_type as account_budget_proposal_type,
    spending_limit_type as spending_limit_type,
    time_type as time_type,
)

__protobuf__: Any

class AccountBudgetProposal(proto.Message):
    resource_name: Any
    id: Any
    billing_setup: Any
    account_budget: Any
    proposal_type: Any
    status: Any
    proposed_name: Any
    approved_start_date_time: Any
    proposed_purchase_order_number: Any
    proposed_notes: Any
    creation_date_time: Any
    approval_date_time: Any
    proposed_start_date_time: Any
    proposed_start_time_type: Any
    proposed_end_date_time: Any
    proposed_end_time_type: Any
    approved_end_date_time: Any
    approved_end_time_type: Any
    proposed_spending_limit_micros: Any
    proposed_spending_limit_type: Any
    approved_spending_limit_micros: Any
    approved_spending_limit_type: Any



from typing import Any

import proto

__protobuf__: Any

class ListOperationErrorEnum(proto.Message):
    class ListOperationError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        REQUIRED_FIELD_MISSING: int
        DUPLICATE_VALUES: int



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import (
    account_budget_proposal as account_budget_proposal,
)

__protobuf__: Any

class GetAccountBudgetProposalRequest(proto.Message):
    resource_name: Any

class MutateAccountBudgetProposalRequest(proto.Message):
    customer_id: Any
    operation: Any
    validate_only: Any

class AccountBudgetProposalOperation(proto.Message):
    update_mask: Any
    create: Any
    remove: Any

class MutateAccountBudgetProposalResponse(proto.Message):
    result: Any

class MutateAccountBudgetProposalResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class UrlFieldErrorEnum(proto.Message):
    class UrlFieldError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_TRACKING_URL_TEMPLATE: int
        INVALID_TAG_IN_TRACKING_URL_TEMPLATE: int
        MISSING_TRACKING_URL_TEMPLATE_TAG: int
        MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE: int
        INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE: int
        MALFORMED_TRACKING_URL_TEMPLATE: int
        MISSING_HOST_IN_TRACKING_URL_TEMPLATE: int
        INVALID_TLD_IN_TRACKING_URL_TEMPLATE: int
        REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG: int
        INVALID_FINAL_URL: int
        INVALID_TAG_IN_FINAL_URL: int
        REDUNDANT_NESTED_FINAL_URL_TAG: int
        MISSING_PROTOCOL_IN_FINAL_URL: int
        INVALID_PROTOCOL_IN_FINAL_URL: int
        MALFORMED_FINAL_URL: int
        MISSING_HOST_IN_FINAL_URL: int
        INVALID_TLD_IN_FINAL_URL: int
        INVALID_FINAL_MOBILE_URL: int
        INVALID_TAG_IN_FINAL_MOBILE_URL: int
        REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG: int
        MISSING_PROTOCOL_IN_FINAL_MOBILE_URL: int
        INVALID_PROTOCOL_IN_FINAL_MOBILE_URL: int
        MALFORMED_FINAL_MOBILE_URL: int
        MISSING_HOST_IN_FINAL_MOBILE_URL: int
        INVALID_TLD_IN_FINAL_MOBILE_URL: int
        INVALID_FINAL_APP_URL: int
        INVALID_TAG_IN_FINAL_APP_URL: int
        REDUNDANT_NESTED_FINAL_APP_URL_TAG: int
        MULTIPLE_APP_URLS_FOR_OSTYPE: int
        INVALID_OSTYPE: int
        INVALID_PROTOCOL_FOR_APP_URL: int
        INVALID_PACKAGE_ID_FOR_APP_URL: int
        URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT: int
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY: int
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE: int
        INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE: int
        REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG: int
        MISSING_PROTOCOL: int
        INVALID_PROTOCOL: int
        INVALID_URL: int
        DESTINATION_URL_DEPRECATED: int
        INVALID_TAG_IN_URL: int
        MISSING_URL_TAG: int
        DUPLICATE_URL_ID: int
        INVALID_URL_ID: int
        FINAL_URL_SUFFIX_MALFORMED: int
        INVALID_TAG_IN_FINAL_URL_SUFFIX: int
        INVALID_TOP_LEVEL_DOMAIN: int
        MALFORMED_TOP_LEVEL_DOMAIN: int
        MALFORMED_URL: int
        MISSING_HOST: int
        NULL_CUSTOM_PARAMETER_VALUE: int



from typing import Any

import proto

__protobuf__: Any

class DisplayUploadProductTypeEnum(proto.Message):
    class DisplayUploadProductType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        HTML5_UPLOAD_AD: int
        DYNAMIC_HTML5_EDUCATION_AD: int
        DYNAMIC_HTML5_FLIGHT_AD: int
        DYNAMIC_HTML5_HOTEL_RENTAL_AD: int
        DYNAMIC_HTML5_JOB_AD: int
        DYNAMIC_HTML5_LOCAL_AD: int
        DYNAMIC_HTML5_REAL_ESTATE_AD: int
        DYNAMIC_HTML5_CUSTOM_AD: int
        DYNAMIC_HTML5_TRAVEL_AD: int
        DYNAMIC_HTML5_HOTEL_AD: int



from typing import Any

import proto

__protobuf__: Any

class CalloutPlaceholderFieldEnum(proto.Message):
    class CalloutPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CALLOUT_TEXT: int



from typing import Any

import proto

__protobuf__: Any

class LeadFormPostSubmitCallToActionTypeEnum(proto.Message):
    class LeadFormPostSubmitCallToActionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        VISIT_SITE: int
        DOWNLOAD: int
        LEARN_MORE: int
        SHOP_NOW: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import (
    criteria as criteria,
    extensions as extensions,
)
from google.ads.googleads.v8.enums.types import (
    feed_item_status as feed_item_status,
    feed_item_target_device as feed_item_target_device,
)

__protobuf__: Any

class ExtensionFeedItem(proto.Message):
    resource_name: Any
    id: Any
    extension_type: Any
    start_date_time: Any
    end_date_time: Any
    ad_schedules: Any
    device: Any
    targeted_geo_target_constant: Any
    targeted_keyword: Any
    status: Any
    sitelink_feed_item: Any
    structured_snippet_feed_item: Any
    app_feed_item: Any
    call_feed_item: Any
    callout_feed_item: Any
    text_message_feed_item: Any
    price_feed_item: Any
    promotion_feed_item: Any
    location_feed_item: Any
    affiliate_location_feed_item: Any
    hotel_callout_feed_item: Any
    image_feed_item: Any
    targeted_campaign: Any
    targeted_ad_group: Any



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanCampaignKeywordErrorEnum(proto.Message):
    class KeywordPlanCampaignKeywordError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CAMPAIGN_KEYWORD_IS_POSITIVE: int



from typing import Any

import proto

__protobuf__: Any

class ContentLabelTypeEnum(proto.Message):
    class ContentLabelType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SEXUALLY_SUGGESTIVE: int
        BELOW_THE_FOLD: int
        PARKED_DOMAIN: int
        JUVENILE: int
        PROFANITY: int
        TRAGEDY: int
        VIDEO: int
        VIDEO_RATING_DV_G: int
        VIDEO_RATING_DV_PG: int
        VIDEO_RATING_DV_T: int
        VIDEO_RATING_DV_MA: int
        VIDEO_NOT_YET_RATED: int
        EMBEDDED_VIDEO: int
        LIVE_STREAMING_VIDEO: int
        SOCIAL_ISSUES: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v8.resources.types import recommendation
from google.ads.googleads.v8.services.types import recommendation_service

class RecommendationServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: ga_credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def get_recommendation(
        self,
    ) -> typing.Callable[
        [recommendation_service.GetRecommendationRequest], recommendation.Recommendation
    ]: ...
    @property
    def apply_recommendation(
        self,
    ) -> typing.Callable[
        [recommendation_service.ApplyRecommendationRequest],
        recommendation_service.ApplyRecommendationResponse,
    ]: ...
    @property
    def dismiss_recommendation(
        self,
    ) -> typing.Callable[
        [recommendation_service.DismissRecommendationRequest],
        recommendation_service.DismissRecommendationResponse,
    ]: ...



from typing import Any

import proto

from google.ads.googleads.v8.common.types import (
    feed_item_set_filter_type_infos as feed_item_set_filter_type_infos,
)
from google.ads.googleads.v8.enums.types import (
    feed_item_set_status as feed_item_set_status,
)

__protobuf__: Any

class FeedItemSet(proto.Message):
    resource_name: Any
    feed: Any
    feed_item_set_id: Any
    display_name: Any
    status: Any
    dynamic_location_set_filter: Any
    dynamic_affiliate_location_set_filter: Any



from .base import (
    AdGroupAudienceViewServiceTransport as AdGroupAudienceViewServiceTransport,
)
from .grpc import (
    AdGroupAudienceViewServiceGrpcTransport as AdGroupAudienceViewServiceGrpcTransport,
)



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import month_of_year as month_of_year
from google.ads.googleads.v8.resources.types import invoice as invoice

__protobuf__: Any

class ListInvoicesRequest(proto.Message):
    customer_id: Any
    billing_setup: Any
    issue_year: Any
    issue_month: Any

class ListInvoicesResponse(proto.Message):
    invoices: Any



from typing import Any

import proto

__protobuf__: Any

class MediaFileErrorEnum(proto.Message):
    class MediaFileError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CANNOT_CREATE_STANDARD_ICON: int
        CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES: int
        CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA: int
        DUPLICATE_MEDIA: int
        EMPTY_FIELD: int
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS: int
        FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE: int
        INVALID_MEDIA_FILE_ID: int
        INVALID_MEDIA_SUB_TYPE: int
        INVALID_MEDIA_FILE_TYPE: int
        INVALID_MIME_TYPE: int
        INVALID_REFERENCE_ID: int
        INVALID_YOU_TUBE_ID: int
        MEDIA_FILE_FAILED_TRANSCODING: int
        MEDIA_NOT_TRANSCODED: int
        MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE: int
        NO_FIELDS_SPECIFIED: int
        NULL_REFERENCE_ID_AND_MEDIA_ID: int
        TOO_LONG: int
        UNSUPPORTED_TYPE: int
        YOU_TUBE_SERVICE_UNAVAILABLE: int
        YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION: int
        YOU_TUBE_VIDEO_NOT_FOUND: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    frequency_cap_event_type as frequency_cap_event_type,
    frequency_cap_level as frequency_cap_level,
    frequency_cap_time_unit as frequency_cap_time_unit,
)

__protobuf__: Any

class FrequencyCapEntry(proto.Message):
    key: Any
    cap: Any

class FrequencyCapKey(proto.Message):
    level: Any
    event_type: Any
    time_unit: Any
    time_length: Any



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials

from google.ads.googleads.v7.resources.types import conversion_custom_variable
from google.ads.googleads.v7.services.types import conversion_custom_variable_service

class ConversionCustomVariableServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def get_conversion_custom_variable(
        self,
    ) -> typing.Callable[
        [conversion_custom_variable_service.GetConversionCustomVariableRequest],
        conversion_custom_variable.ConversionCustomVariable,
    ]: ...
    @property
    def mutate_conversion_custom_variables(
        self,
    ) -> typing.Callable[
        [conversion_custom_variable_service.MutateConversionCustomVariablesRequest],
        conversion_custom_variable_service.MutateConversionCustomVariablesResponse,
    ]: ...



from typing import Any

import proto

__protobuf__: Any

class MediaUploadErrorEnum(proto.Message):
    class MediaUploadError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FILE_TOO_BIG: int
        UNPARSEABLE_IMAGE: int
        ANIMATED_IMAGE_NOT_ALLOWED: int
        FORMAT_NOT_ALLOWED: int
        EXTERNAL_URL_NOT_ALLOWED: int
        INVALID_URL_REFERENCE: int
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY: int
        ANIMATED_VISUAL_EFFECT: int
        ANIMATION_TOO_LONG: int
        ASPECT_RATIO_NOT_ALLOWED: int
        AUDIO_NOT_ALLOWED_IN_MEDIA_BUNDLE: int
        CMYK_JPEG_NOT_ALLOWED: int
        FLASH_NOT_ALLOWED: int
        FRAME_RATE_TOO_HIGH: int
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED: int
        IMAGE_CONSTRAINTS_VIOLATED: int
        INVALID_MEDIA_BUNDLE: int
        INVALID_MEDIA_BUNDLE_ENTRY: int
        INVALID_MIME_TYPE: int
        INVALID_PATH: int
        LAYOUT_PROBLEM: int
        MALFORMED_URL: int
        MEDIA_BUNDLE_NOT_ALLOWED: int
        MEDIA_BUNDLE_NOT_COMPATIBLE_TO_PRODUCT_TYPE: int
        MEDIA_BUNDLE_REJECTED_BY_MULTIPLE_ASSET_SPECS: int
        TOO_MANY_FILES_IN_MEDIA_BUNDLE: int
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT: int
        UNSUPPORTED_HTML5_FEATURE: int
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT: int
        VIDEO_FILE_NAME_TOO_LONG: int
        VIDEO_MULTIPLE_FILES_WITH_SAME_NAME: int
        VIDEO_NOT_ALLOWED_IN_MEDIA_BUNDLE: int
        CANNOT_UPLOAD_MEDIA_TYPE_THROUGH_API: int
        DIMENSIONS_NOT_ALLOWED: int



from typing import Any

import proto

__protobuf__: Any

class CustomerMatchUploadKeyTypeEnum(proto.Message):
    class CustomerMatchUploadKeyType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CONTACT_INFO: int
        CRM_ID: int
        MOBILE_ADVERTISING_ID: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    geo_target_constant_status as geo_target_constant_status,
)

__protobuf__: Any

class GeoTargetConstant(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    country_code: Any
    target_type: Any
    status: Any
    canonical_name: Any
    parent_geo_target: Any



from .base import (
    ParentalStatusViewServiceTransport as ParentalStatusViewServiceTransport,
)
from .grpc import (
    ParentalStatusViewServiceGrpcTransport as ParentalStatusViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class ReachPlanAdLengthEnum(proto.Message):
    class ReachPlanAdLength(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SIX_SECONDS: int
        FIFTEEN_OR_TWENTY_SECONDS: int
        TWENTY_SECONDS_OR_MORE: int



from typing import Any

import proto

__protobuf__: Any

class FeedItemTargetDeviceEnum(proto.Message):
    class FeedItemTargetDevice(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MOBILE: int



from typing import Any

import proto

__protobuf__: Any

class UserListSizeRangeEnum(proto.Message):
    class UserListSizeRange(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LESS_THAN_FIVE_HUNDRED: int
        LESS_THAN_ONE_THOUSAND: int
        ONE_THOUSAND_TO_TEN_THOUSAND: int
        TEN_THOUSAND_TO_FIFTY_THOUSAND: int
        FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND: int
        ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND: int
        THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND: int
        FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION: int
        ONE_MILLION_TO_TWO_MILLION: int
        TWO_MILLION_TO_THREE_MILLION: int
        THREE_MILLION_TO_FIVE_MILLION: int
        FIVE_MILLION_TO_TEN_MILLION: int
        TEN_MILLION_TO_TWENTY_MILLION: int
        TWENTY_MILLION_TO_THIRTY_MILLION: int
        THIRTY_MILLION_TO_FIFTY_MILLION: int
        OVER_FIFTY_MILLION: int



from typing import Any

import proto

__protobuf__: Any

class HeaderErrorEnum(proto.Message):
    class HeaderError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_LOGIN_CUSTOMER_ID: int
        INVALID_LINKED_CUSTOMER_ID: int



from typing import Callable, Optional, Sequence, Tuple

import grpc
from google.api_core import gapic_v1
from google.auth import credentials

from google.ads.googleads.v7.resources.types import ad_group_asset
from google.ads.googleads.v7.services.types import ad_group_asset_service

from .base import AdGroupAssetServiceTransport

class AdGroupAssetServiceGrpcTransport(AdGroupAssetServiceTransport):
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: credentials.Credentials = ...,
        credentials_file: str = ...,
        scopes: Sequence[str] = ...,
        channel: grpc.Channel = ...,
        api_mtls_endpoint: str = ...,
        client_cert_source: Callable[[], Tuple[bytes, bytes]] = ...,
        ssl_channel_credentials: grpc.ChannelCredentials = ...,
        quota_project_id: Optional[str] = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @classmethod
    def create_channel(
        cls,
        host: str = ...,
        credentials: credentials.Credentials = ...,
        scopes: Optional[Sequence[str]] = ...,
        **kwargs
    ) -> grpc.Channel: ...
    @property
    def grpc_channel(self) -> grpc.Channel: ...
    @property
    def get_ad_group_asset(
        self,
    ) -> Callable[
        [ad_group_asset_service.GetAdGroupAssetRequest], ad_group_asset.AdGroupAsset
    ]: ...
    @property
    def mutate_ad_group_assets(
        self,
    ) -> Callable[
        [ad_group_asset_service.MutateAdGroupAssetsRequest],
        ad_group_asset_service.MutateAdGroupAssetsResponse,
    ]: ...



from typing import Any

import proto

__protobuf__: Any

class ChangeStatusOperationEnum(proto.Message):
    class ChangeStatusOperation(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ADDED: int
        CHANGED: int
        REMOVED: int



from typing import Any

import proto

__protobuf__: Any

class ManagerLinkErrorEnum(proto.Message):
    class ManagerLinkError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING: int
        TOO_MANY_MANAGERS: int
        TOO_MANY_INVITES: int
        ALREADY_INVITED_BY_THIS_MANAGER: int
        ALREADY_MANAGED_BY_THIS_MANAGER: int
        ALREADY_MANAGED_IN_HIERARCHY: int
        DUPLICATE_CHILD_FOUND: int
        CLIENT_HAS_NO_ADMIN_USER: int
        MAX_DEPTH_EXCEEDED: int
        CYCLE_NOT_ALLOWED: int
        TOO_MANY_ACCOUNTS: int
        TOO_MANY_ACCOUNTS_AT_MANAGER: int
        NON_OWNER_USER_CANNOT_MODIFY_LINK: int
        SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS: int
        CLIENT_OUTSIDE_TREE: int
        INVALID_STATUS_CHANGE: int
        INVALID_CHANGE: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    conversion_custom_variable_status as conversion_custom_variable_status,
)

__protobuf__: Any

class ConversionCustomVariable(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    tag: Any
    status: Any
    owner_customer: Any



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import media_type as media_type

__protobuf__: Any

class MediaFile(proto.Message):
    resource_name: Any
    id: Any
    type_: Any
    mime_type: Any
    source_url: Any
    name: Any
    file_size: Any
    image: Any
    media_bundle: Any
    audio: Any
    video: Any

class MediaImage(proto.Message):
    data: Any
    full_size_image_url: Any
    preview_size_image_url: Any

class MediaBundle(proto.Message):
    data: Any
    url: Any

class MediaAudio(proto.Message):
    ad_duration_millis: Any

class MediaVideo(proto.Message):
    ad_duration_millis: Any
    youtube_video_id: Any
    advertising_id_code: Any
    isci_code: Any



from typing import Any

import proto

__protobuf__: Any

class ProductBiddingCategoryStatusEnum(proto.Message):
    class ProductBiddingCategoryStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ACTIVE: int
        OBSOLETE: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import month_of_year as month_of_year

__protobuf__: Any

class DateRange(proto.Message):
    start_date: Any
    end_date: Any

class YearMonthRange(proto.Message):
    start: Any
    end: Any

class YearMonth(proto.Message):
    year: Any
    month: Any



from typing import Any

import proto

__protobuf__: Any

class DatabaseErrorEnum(proto.Message):
    class DatabaseError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CONCURRENT_MODIFICATION: int
        DATA_CONSTRAINT_VIOLATION: int
        REQUEST_TOO_LARGE: int



from typing import Any

import proto

__protobuf__: Any

class ProductConditionEnum(proto.Message):
    class ProductCondition(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NEW: int
        REFURBISHED: int
        USED: int



from typing import Any

import proto

__protobuf__: Any

class FeedErrorEnum(proto.Message):
    class FeedError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ATTRIBUTE_NAMES_NOT_UNIQUE: int
        ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES: int
        CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED: int
        CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED: int
        CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED: int
        CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE: int
        FEED_REMOVED: int
        INVALID_ORIGIN_VALUE: int
        FEED_ORIGIN_IS_NOT_USER: int
        INVALID_AUTH_TOKEN_FOR_EMAIL: int
        INVALID_EMAIL: int
        DUPLICATE_FEED_NAME: int
        INVALID_FEED_NAME: int
        MISSING_OAUTH_INFO: int
        NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY: int
        TOO_MANY_ATTRIBUTES: int
        INVALID_BUSINESS_ACCOUNT: int
        BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT: int
        INVALID_AFFILIATE_CHAIN_ID: int
        DUPLICATE_SYSTEM_FEED: int
        GMB_ACCESS_ERROR: int
        CANNOT_HAVE_LOCATION_AND_AFFILIATE_LOCATION_FEEDS: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    customer_match_upload_key_type as customer_match_upload_key_type,
    user_list_combined_rule_operator as user_list_combined_rule_operator,
    user_list_crm_data_source_type as user_list_crm_data_source_type,
    user_list_date_rule_item_operator as user_list_date_rule_item_operator,
    user_list_logical_rule_operator as user_list_logical_rule_operator,
    user_list_number_rule_item_operator as user_list_number_rule_item_operator,
    user_list_prepopulation_status as user_list_prepopulation_status,
    user_list_rule_type as user_list_rule_type,
    user_list_string_rule_item_operator as user_list_string_rule_item_operator,
)

__protobuf__: Any

class SimilarUserListInfo(proto.Message):
    seed_user_list: Any

class CrmBasedUserListInfo(proto.Message):
    app_id: Any
    upload_key_type: Any
    data_source_type: Any

class UserListRuleInfo(proto.Message):
    rule_type: Any
    rule_item_groups: Any

class UserListRuleItemGroupInfo(proto.Message):
    rule_items: Any

class UserListRuleItemInfo(proto.Message):
    name: Any
    number_rule_item: Any
    string_rule_item: Any
    date_rule_item: Any

class UserListDateRuleItemInfo(proto.Message):
    operator: Any
    value: Any
    offset_in_days: Any

class UserListNumberRuleItemInfo(proto.Message):
    operator: Any
    value: Any

class UserListStringRuleItemInfo(proto.Message):
    operator: Any
    value: Any

class CombinedRuleUserListInfo(proto.Message):
    left_operand: Any
    right_operand: Any
    rule_operator: Any

class DateSpecificRuleUserListInfo(proto.Message):
    rule: Any
    start_date: Any
    end_date: Any

class ExpressionRuleUserListInfo(proto.Message):
    rule: Any

class RuleBasedUserListInfo(proto.Message):
    prepopulation_status: Any
    combined_rule_user_list: Any
    date_specific_rule_user_list: Any
    expression_rule_user_list: Any

class LogicalUserListInfo(proto.Message):
    rules: Any

class UserListLogicalRuleInfo(proto.Message):
    operator: Any
    rule_operands: Any

class LogicalUserListOperandInfo(proto.Message):
    user_list: Any

class BasicUserListInfo(proto.Message):
    actions: Any

class UserListActionInfo(proto.Message):
    conversion_action: Any
    remarketing_action: Any



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    change_status_operation as change_status_operation,
    change_status_resource_type as change_status_resource_type,
)

__protobuf__: Any

class ChangeStatus(proto.Message):
    resource_name: Any
    last_change_date_time: Any
    resource_type: Any
    campaign: Any
    ad_group: Any
    resource_status: Any
    ad_group_ad: Any
    ad_group_criterion: Any
    campaign_criterion: Any
    feed: Any
    feed_item: Any
    ad_group_feed: Any
    campaign_feed: Any
    ad_group_bid_modifier: Any



from .base import (
    CampaignExperimentServiceTransport as CampaignExperimentServiceTransport,
)
from .grpc import (
    CampaignExperimentServiceGrpcTransport as CampaignExperimentServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class SearchEngineResultsPageTypeEnum(proto.Message):
    class SearchEngineResultsPageType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ADS_ONLY: int
        ORGANIC_ONLY: int
        ADS_AND_ORGANIC: int



from typing import Any

import proto

__protobuf__: Any

class TargetImpressionShareLocationEnum(proto.Message):
    class TargetImpressionShareLocation(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ANYWHERE_ON_PAGE: int
        TOP_OF_PAGE: int
        ABSOLUTE_TOP_OF_PAGE: int



from typing import Any

import proto

__protobuf__: Any

class BudgetPeriodEnum(proto.Message):
    class BudgetPeriod(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DAILY: int
        CUSTOM_PERIOD: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import simulation as simulation
from google.ads.googleads.v7.enums.types import (
    simulation_modification_method as simulation_modification_method,
    simulation_type as simulation_type,
)

__protobuf__: Any

class CampaignSimulation(proto.Message):
    resource_name: Any
    campaign_id: Any
    type_: Any
    modification_method: Any
    start_date: Any
    end_date: Any
    cpc_bid_point_list: Any
    target_cpa_point_list: Any
    target_roas_point_list: Any
    target_impression_share_point_list: Any
    budget_point_list: Any



from typing import Any

import proto

__protobuf__: Any

class SharedSetTypeEnum(proto.Message):
    class SharedSetType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NEGATIVE_KEYWORDS: int
        NEGATIVE_PLACEMENTS: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v8.resources.types import webpage_view
from google.ads.googleads.v8.services.types import webpage_view_service

class WebpageViewServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: ga_credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def get_webpage_view(
        self,
    ) -> typing.Callable[
        [webpage_view_service.GetWebpageViewRequest], webpage_view.WebpageView
    ]: ...



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials

from google.ads.googleads.v7.resources.types import distance_view
from google.ads.googleads.v7.services.types import distance_view_service

class DistanceViewServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def get_distance_view(
        self,
    ) -> typing.Callable[
        [distance_view_service.GetDistanceViewRequest], distance_view.DistanceView
    ]: ...



from typing import Any

import proto

__protobuf__: Any

class AssetErrorEnum(proto.Message):
    class AssetError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CUSTOMER_NOT_ON_ALLOWLIST_FOR_ASSET_TYPE: int
        DUPLICATE_ASSET: int
        DUPLICATE_ASSET_NAME: int
        ASSET_DATA_IS_MISSING: int
        CANNOT_MODIFY_ASSET_NAME: int
        FIELD_INCOMPATIBLE_WITH_ASSET_TYPE: int
        INVALID_CALL_TO_ACTION_TEXT: int
        LEAD_FORM_INVALID_FIELDS_COMBINATION: int
        LEAD_FORM_MISSING_AGREEMENT: int
        INVALID_ASSET_STATUS: int
        FIELD_CANNOT_BE_MODIFIED_FOR_ASSET_TYPE: int
        SCHEDULES_CANNOT_OVERLAP: int
        PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF: int
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT: int
        TOO_MANY_DECIMAL_PLACES_SPECIFIED: int
        DUPLICATE_ASSETS_WITH_DIFFERENT_FIELD_VALUE: int



from typing import Any

import proto

__protobuf__: Any

class FeedOriginEnum(proto.Message):
    class FeedOrigin(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        USER: int
        GOOGLE: int



# Names in __all__ with no definition:
#   AccessInvitationStatusEnum
#   AccessReasonEnum
#   AccessRoleEnum
#   AccountBudgetProposalStatusEnum
#   AccountBudgetProposalTypeEnum
#   AccountBudgetStatusEnum
#   AccountLinkStatusEnum
#   AdCustomizerPlaceholderFieldEnum
#   AdDestinationTypeEnum
#   AdGroupAdRotationModeEnum
#   AdGroupAdStatusEnum
#   AdGroupCriterionApprovalStatusEnum
#   AdGroupCriterionStatusEnum
#   AdGroupStatusEnum
#   AdGroupTypeEnum
#   AdNetworkTypeEnum
#   AdServingOptimizationStatusEnum
#   AdStrengthEnum
#   AdTypeEnum
#   AdvertisingChannelSubTypeEnum
#   AdvertisingChannelTypeEnum
#   AffiliateLocationFeedRelationshipTypeEnum
#   AffiliateLocationPlaceholderFieldEnum
#   AgeRangeTypeEnum
#   AppCampaignAppStoreEnum
#   AppCampaignBiddingStrategyGoalTypeEnum
#   AppPaymentModelTypeEnum
#   AppPlaceholderFieldEnum
#   AppStoreEnum
#   AppUrlOperatingSystemTypeEnum
#   AssetFieldTypeEnum
#   AssetLinkStatusEnum
#   AssetPerformanceLabelEnum
#   AssetTypeEnum
#   AttributionModelEnum
#   BatchJobStatusEnum
#   BidModifierSourceEnum
#   BiddingSourceEnum
#   BiddingStrategyStatusEnum
#   BiddingStrategyTypeEnum
#   BillingSetupStatusEnum
#   BrandSafetySuitabilityEnum
#   BudgetCampaignAssociationStatusEnum
#   BudgetDeliveryMethodEnum
#   BudgetPeriodEnum
#   BudgetStatusEnum
#   BudgetTypeEnum
#   CallConversionReportingStateEnum
#   CallPlaceholderFieldEnum
#   CallTrackingDisplayLocationEnum
#   CallTypeEnum
#   CalloutPlaceholderFieldEnum
#   CampaignCriterionStatusEnum
#   CampaignDraftStatusEnum
#   CampaignExperimentStatusEnum
#   CampaignExperimentTrafficSplitTypeEnum
#   CampaignExperimentTypeEnum
#   CampaignServingStatusEnum
#   CampaignSharedSetStatusEnum
#   CampaignStatusEnum
#   ChangeClientTypeEnum
#   ChangeEventResourceTypeEnum
#   ChangeStatusOperationEnum
#   ChangeStatusResourceTypeEnum
#   ClickTypeEnum
#   CombinedAudienceStatusEnum
#   ContentLabelTypeEnum
#   ConversionActionCategoryEnum
#   ConversionActionCountingTypeEnum
#   ConversionActionStatusEnum
#   ConversionActionTypeEnum
#   ConversionAdjustmentTypeEnum
#   ConversionAttributionEventTypeEnum
#   ConversionCustomVariableStatusEnum
#   ConversionLagBucketEnum
#   ConversionOrAdjustmentLagBucketEnum
#   CriterionCategoryChannelAvailabilityModeEnum
#   CriterionCategoryLocaleAvailabilityModeEnum
#   CriterionSystemServingStatusEnum
#   CriterionTypeEnum
#   CustomAudienceMemberTypeEnum
#   CustomAudienceStatusEnum
#   CustomAudienceTypeEnum
#   CustomInterestMemberTypeEnum
#   CustomInterestStatusEnum
#   CustomInterestTypeEnum
#   CustomPlaceholderFieldEnum
#   CustomerMatchUploadKeyTypeEnum
#   CustomerPayPerConversionEligibilityFailureReasonEnum
#   DataDrivenModelStatusEnum
#   DayOfWeekEnum
#   DeviceEnum
#   DisplayAdFormatSettingEnum
#   DisplayUploadProductTypeEnum
#   DistanceBucketEnum
#   DsaPageFeedCriterionFieldEnum
#   EducationPlaceholderFieldEnum
#   ExtensionSettingDeviceEnum
#   ExtensionTypeEnum
#   ExternalConversionSourceEnum
#   FeedAttributeTypeEnum
#   FeedItemQualityApprovalStatusEnum
#   FeedItemQualityDisapprovalReasonEnum
#   FeedItemSetStatusEnum
#   FeedItemSetStringFilterTypeEnum
#   FeedItemStatusEnum
#   FeedItemTargetDeviceEnum
#   FeedItemTargetStatusEnum
#   FeedItemTargetTypeEnum
#   FeedItemValidationStatusEnum
#   FeedLinkStatusEnum
#   FeedMappingCriterionTypeEnum
#   FeedMappingStatusEnum
#   FeedOriginEnum
#   FeedStatusEnum
#   FlightPlaceholderFieldEnum
#   FrequencyCapEventTypeEnum
#   FrequencyCapLevelEnum
#   FrequencyCapTimeUnitEnum
#   GenderTypeEnum
#   GeoTargetConstantStatusEnum
#   GeoTargetingRestrictionEnum
#   GeoTargetingTypeEnum
#   GoogleAdsFieldCategoryEnum
#   GoogleAdsFieldDataTypeEnum
#   GoogleVoiceCallStatusEnum
#   HotelDateSelectionTypeEnum
#   HotelPlaceholderFieldEnum
#   HotelPriceBucketEnum
#   HotelRateTypeEnum
#   ImagePlaceholderFieldEnum
#   IncomeRangeTypeEnum
#   InteractionEventTypeEnum
#   InteractionTypeEnum
#   InvoiceTypeEnum
#   JobPlaceholderFieldEnum
#   KeywordMatchTypeEnum
#   KeywordPlanAggregateMetricTypeEnum
#   KeywordPlanCompetitionLevelEnum
#   KeywordPlanConceptGroupTypeEnum
#   KeywordPlanForecastIntervalEnum
#   KeywordPlanKeywordAnnotationEnum
#   KeywordPlanNetworkEnum
#   LabelStatusEnum
#   LeadFormCallToActionTypeEnum
#   LeadFormDesiredIntentEnum
#   LeadFormFieldUserInputTypeEnum
#   LeadFormPostSubmitCallToActionTypeEnum
#   LegacyAppInstallAdAppStoreEnum
#   LinkedAccountTypeEnum
#   ListingGroupTypeEnum
#   LocalPlaceholderFieldEnum
#   LocationExtensionTargetingCriterionFieldEnum
#   LocationGroupRadiusUnitsEnum
#   LocationPlaceholderFieldEnum
#   LocationSourceTypeEnum
#   ManagerLinkStatusEnum
#   MatchingFunctionContextTypeEnum
#   MatchingFunctionOperatorEnum
#   MediaTypeEnum
#   MerchantCenterLinkStatusEnum
#   MessagePlaceholderFieldEnum
#   MimeTypeEnum
#   MinuteOfHourEnum
#   MobileAppVendorEnum
#   MobileDeviceTypeEnum
#   MonthOfYearEnum
#   NegativeGeoTargetTypeEnum
#   OfflineUserDataJobFailureReasonEnum
#   OfflineUserDataJobStatusEnum
#   OfflineUserDataJobTypeEnum
#   OperatingSystemVersionOperatorTypeEnum
#   OptimizationGoalTypeEnum
#   ParentalStatusTypeEnum
#   PaymentModeEnum
#   PlaceholderTypeEnum
#   PlacementTypeEnum
#   PolicyApprovalStatusEnum
#   PolicyReviewStatusEnum
#   PolicyTopicEntryTypeEnum
#   PolicyTopicEvidenceDestinationMismatchUrlTypeEnum
#   PolicyTopicEvidenceDestinationNotWorkingDeviceEnum
#   PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum
#   PositiveGeoTargetTypeEnum
#   PreferredContentTypeEnum
#   PriceExtensionPriceQualifierEnum
#   PriceExtensionPriceUnitEnum
#   PriceExtensionTypeEnum
#   PricePlaceholderFieldEnum
#   ProductBiddingCategoryLevelEnum
#   ProductBiddingCategoryStatusEnum
#   ProductChannelEnum
#   ProductChannelExclusivityEnum
#   ProductConditionEnum
#   ProductCustomAttributeIndexEnum
#   ProductTypeLevelEnum
#   PromotionExtensionDiscountModifierEnum
#   PromotionExtensionOccasionEnum
#   PromotionPlaceholderFieldEnum
#   ProximityRadiusUnitsEnum
#   QualityScoreBucketEnum
#   ReachPlanAdLengthEnum
#   ReachPlanAgeRangeEnum
#   ReachPlanNetworkEnum
#   RealEstatePlaceholderFieldEnum
#   RecommendationTypeEnum
#   ResourceChangeOperationEnum
#   ResourceLimitTypeEnum
#   ResponseContentTypeEnum
#   SearchEngineResultsPageTypeEnum
#   SearchTermMatchTypeEnum
#   SearchTermTargetingStatusEnum
#   ServedAssetFieldTypeEnum
#   SharedSetStatusEnum
#   SharedSetTypeEnum
#   SimulationModificationMethodEnum
#   SimulationTypeEnum
#   SitelinkPlaceholderFieldEnum
#   SlotEnum
#   SpendingLimitTypeEnum
#   StructuredSnippetPlaceholderFieldEnum
#   SummaryRowSettingEnum
#   SystemManagedResourceSourceEnum
#   TargetCpaOptInRecommendationGoalEnum
#   TargetImpressionShareLocationEnum
#   TargetingDimensionEnum
#   TimeTypeEnum
#   TrackingCodePageFormatEnum
#   TrackingCodeTypeEnum
#   TravelPlaceholderFieldEnum
#   UserIdentifierSourceEnum
#   UserInterestTaxonomyTypeEnum
#   UserListAccessStatusEnum
#   UserListClosingReasonEnum
#   UserListCombinedRuleOperatorEnum
#   UserListCrmDataSourceTypeEnum
#   UserListDateRuleItemOperatorEnum
#   UserListLogicalRuleOperatorEnum
#   UserListMembershipStatusEnum
#   UserListNumberRuleItemOperatorEnum
#   UserListPrepopulationStatusEnum
#   UserListRuleTypeEnum
#   UserListSizeRangeEnum
#   UserListStringRuleItemOperatorEnum
#   UserListTypeEnum
#   VanityPharmaDisplayUrlModeEnum
#   VanityPharmaTextEnum
#   WebpageConditionOperandEnum
#   WebpageConditionOperatorEnum



from typing import Any

import proto

__protobuf__: Any

class ImagePlaceholderFieldEnum(proto.Message):
    class ImagePlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ASSET_ID: int



from typing import Any

import proto

__protobuf__: Any

class AppCampaignBiddingStrategyGoalTypeEnum(proto.Message):
    class AppCampaignBiddingStrategyGoalType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        OPTIMIZE_INSTALLS_TARGET_INSTALL_COST: int
        OPTIMIZE_IN_APP_CONVERSIONS_TARGET_INSTALL_COST: int
        OPTIMIZE_IN_APP_CONVERSIONS_TARGET_CONVERSION_COST: int
        OPTIMIZE_RETURN_ON_ADVERTISING_SPEND: int



from typing import Any

import proto

__protobuf__: Any

class TargetCpaOptInRecommendationGoalEnum(proto.Message):
    class TargetCpaOptInRecommendationGoal(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SAME_COST: int
        SAME_CONVERSIONS: int
        SAME_CPA: int
        CLOSEST_CPA: int



from typing import Any

import proto

__protobuf__: Any

class LocationPlaceholderFieldEnum(proto.Message):
    class LocationPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BUSINESS_NAME: int
        ADDRESS_LINE_1: int
        ADDRESS_LINE_2: int
        CITY: int
        PROVINCE: int
        POSTAL_CODE: int
        COUNTRY_CODE: int
        PHONE_NUMBER: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    policy_topic_entry_type as policy_topic_entry_type,
    policy_topic_evidence_destination_mismatch_url_type as policy_topic_evidence_destination_mismatch_url_type,
    policy_topic_evidence_destination_not_working_device as policy_topic_evidence_destination_not_working_device,
    policy_topic_evidence_destination_not_working_dns_error_type as policy_topic_evidence_destination_not_working_dns_error_type,
)

__protobuf__: Any

class PolicyViolationKey(proto.Message):
    policy_name: Any
    violating_text: Any

class PolicyValidationParameter(proto.Message):
    ignorable_policy_topics: Any
    exempt_policy_violation_keys: Any

class PolicyTopicEntry(proto.Message):
    topic: Any
    type_: Any
    evidences: Any
    constraints: Any

class PolicyTopicEvidence(proto.Message):
    class TextList(proto.Message):
        texts: Any
    class WebsiteList(proto.Message):
        websites: Any
    class DestinationTextList(proto.Message):
        destination_texts: Any
    class DestinationMismatch(proto.Message):
        url_types: Any
    class DestinationNotWorking(proto.Message):
        expanded_url: Any
        device: Any
        last_checked_date_time: Any
        dns_error_type: Any
        http_error_code: Any
    website_list: Any
    text_list: Any
    language_code: Any
    destination_text_list: Any
    destination_mismatch: Any
    destination_not_working: Any

class PolicyTopicConstraint(proto.Message):
    class CountryConstraintList(proto.Message):
        total_targeted_countries: Any
        countries: Any
    class ResellerConstraint(proto.Message): ...
    class CountryConstraint(proto.Message):
        country_criterion: Any
    country_constraint_list: Any
    reseller_constraint: Any
    certificate_missing_in_country_list: Any
    certificate_domain_mismatch_in_country_list: Any



from typing import Any

import proto

__protobuf__: Any

class AuthenticationErrorEnum(proto.Message):
    class AuthenticationError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AUTHENTICATION_ERROR: int
        CLIENT_CUSTOMER_ID_INVALID: int
        CUSTOMER_NOT_FOUND: int
        GOOGLE_ACCOUNT_DELETED: int
        GOOGLE_ACCOUNT_COOKIE_INVALID: int
        GOOGLE_ACCOUNT_AUTHENTICATION_FAILED: int
        GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH: int
        LOGIN_COOKIE_REQUIRED: int
        NOT_ADS_USER: int
        OAUTH_TOKEN_INVALID: int
        OAUTH_TOKEN_EXPIRED: int
        OAUTH_TOKEN_DISABLED: int
        OAUTH_TOKEN_REVOKED: int
        OAUTH_TOKEN_HEADER_INVALID: int
        LOGIN_COOKIE_INVALID: int
        USER_ID_INVALID: int
        TWO_STEP_VERIFICATION_NOT_ENROLLED: int
        ADVANCED_PROTECTION_NOT_ENROLLED: int



from typing import Any

import proto

__protobuf__: Any

class ConversionActionErrorEnum(proto.Message):
    class ConversionActionError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DUPLICATE_NAME: int
        DUPLICATE_APP_ID: int
        TWO_CONVERSION_ACTIONS_BIDDING_ON_SAME_APP_DOWNLOAD: int
        BIDDING_ON_SAME_APP_DOWNLOAD_AS_GLOBAL_ACTION: int
        DATA_DRIVEN_MODEL_WAS_NEVER_GENERATED: int
        DATA_DRIVEN_MODEL_EXPIRED: int
        DATA_DRIVEN_MODEL_STALE: int
        DATA_DRIVEN_MODEL_UNKNOWN: int
        CREATION_NOT_SUPPORTED: int
        UPDATE_NOT_SUPPORTED: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import tag_snippet as tag_snippet

__protobuf__: Any

class RemarketingAction(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    tag_snippets: Any



from typing import Any

import proto

__protobuf__: Any

class TravelPlaceholderFieldEnum(proto.Message):
    class TravelPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DESTINATION_ID: int
        ORIGIN_ID: int
        TITLE: int
        DESTINATION_NAME: int
        ORIGIN_NAME: int
        PRICE: int
        FORMATTED_PRICE: int
        SALE_PRICE: int
        FORMATTED_SALE_PRICE: int
        IMAGE_URL: int
        CATEGORY: int
        CONTEXTUAL_KEYWORDS: int
        DESTINATION_ADDRESS: int
        FINAL_URL: int
        FINAL_MOBILE_URLS: int
        TRACKING_URL: int
        ANDROID_APP_LINK: int
        SIMILAR_DESTINATION_IDS: int
        IOS_APP_LINK: int
        IOS_APP_STORE_ID: int



from typing import Any

import proto

__protobuf__: Any

class AccessRoleEnum(proto.Message):
    class AccessRole(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ADMIN: int
        STANDARD: int
        READ_ONLY: int
        EMAIL_ONLY: int



from typing import Any

import proto

__protobuf__: Any

class CustomerUserAccess(proto.Message):
    resource_name: Any
    user_id: Any
    email_address: Any
    access_role: Any
    access_creation_date_time: Any
    inviter_user_email_address: Any



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    conversion_value_rule_status as conversion_value_rule_status,
    value_rule_device_type as value_rule_device_type,
    value_rule_geo_location_match_type as value_rule_geo_location_match_type,
    value_rule_operation as value_rule_operation,
)

__protobuf__: Any

class ConversionValueRule(proto.Message):
    class ValueRuleAction(proto.Message):
        operation: Any
        value: Any
    class ValueRuleGeoLocationCondition(proto.Message):
        excluded_geo_target_constants: Any
        excluded_geo_match_type: Any
        geo_target_constants: Any
        geo_match_type: Any
    class ValueRuleAudienceCondition(proto.Message):
        user_lists: Any
        user_interests: Any
    class ValueRuleDeviceCondition(proto.Message):
        device_types: Any
    resource_name: Any
    id: Any
    action: Any
    geo_location_condition: Any
    device_condition: Any
    audience_condition: Any
    owner_customer: Any
    status: Any



from typing import Any

import proto

__protobuf__: Any

class MimeTypeEnum(proto.Message):
    class MimeType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        IMAGE_JPEG: int
        IMAGE_GIF: int
        IMAGE_PNG: int
        FLASH: int
        TEXT_HTML: int
        PDF: int
        MSWORD: int
        MSEXCEL: int
        RTF: int
        AUDIO_WAV: int
        AUDIO_MP3: int
        HTML5_AD_ZIP: int



from .base import (
    BiddingStrategySimulationServiceTransport as BiddingStrategySimulationServiceTransport,
)
from .grpc import (
    BiddingStrategySimulationServiceGrpcTransport as BiddingStrategySimulationServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class QueryErrorEnum(proto.Message):
    class QueryError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        QUERY_ERROR: int
        BAD_ENUM_CONSTANT: int
        BAD_ESCAPE_SEQUENCE: int
        BAD_FIELD_NAME: int
        BAD_LIMIT_VALUE: int
        BAD_NUMBER: int
        BAD_OPERATOR: int
        BAD_PARAMETER_NAME: int
        BAD_PARAMETER_VALUE: int
        BAD_RESOURCE_TYPE_IN_FROM_CLAUSE: int
        BAD_SYMBOL: int
        BAD_VALUE: int
        DATE_RANGE_TOO_WIDE: int
        DATE_RANGE_TOO_NARROW: int
        EXPECTED_AND: int
        EXPECTED_BY: int
        EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE: int
        EXPECTED_FILTERS_ON_DATE_RANGE: int
        EXPECTED_FROM: int
        EXPECTED_LIST: int
        EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE: int
        EXPECTED_SELECT: int
        EXPECTED_SINGLE_VALUE: int
        EXPECTED_VALUE_WITH_BETWEEN_OPERATOR: int
        INVALID_DATE_FORMAT: int
        INVALID_STRING_VALUE: int
        INVALID_VALUE_WITH_BETWEEN_OPERATOR: int
        INVALID_VALUE_WITH_DURING_OPERATOR: int
        INVALID_VALUE_WITH_LIKE_OPERATOR: int
        OPERATOR_FIELD_MISMATCH: int
        PROHIBITED_EMPTY_LIST_IN_CONDITION: int
        PROHIBITED_ENUM_CONSTANT: int
        PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE: int
        PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE: int
        PROHIBITED_FIELD_IN_SELECT_CLAUSE: int
        PROHIBITED_FIELD_IN_WHERE_CLAUSE: int
        PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE: int
        PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE: int
        PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE: int
        PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE: int
        PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE: int
        PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE: int
        LIMIT_VALUE_TOO_LOW: int
        PROHIBITED_NEWLINE_IN_STRING: int
        PROHIBITED_VALUE_COMBINATION_IN_LIST: int
        PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR: int
        STRING_NOT_TERMINATED: int
        TOO_MANY_SEGMENTS: int
        UNEXPECTED_END_OF_QUERY: int
        UNEXPECTED_FROM_CLAUSE: int
        UNRECOGNIZED_FIELD: int
        UNEXPECTED_INPUT: int
        REQUESTED_METRICS_FOR_MANAGER: int
        FILTER_HAS_TOO_MANY_VALUES: int



from typing import Any

import proto

__protobuf__: Any

class RequestErrorEnum(proto.Message):
    class RequestError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        RESOURCE_NAME_MISSING: int
        RESOURCE_NAME_MALFORMED: int
        BAD_RESOURCE_ID: int
        INVALID_CUSTOMER_ID: int
        OPERATION_REQUIRED: int
        RESOURCE_NOT_FOUND: int
        INVALID_PAGE_TOKEN: int
        EXPIRED_PAGE_TOKEN: int
        INVALID_PAGE_SIZE: int
        REQUIRED_FIELD_MISSING: int
        IMMUTABLE_FIELD: int
        TOO_MANY_MUTATE_OPERATIONS: int
        CANNOT_BE_EXECUTED_BY_MANAGER_ACCOUNT: int
        CANNOT_MODIFY_FOREIGN_FIELD: int
        INVALID_ENUM_VALUE: int
        DEVELOPER_TOKEN_PARAMETER_MISSING: int
        LOGIN_CUSTOMER_ID_PARAMETER_MISSING: int
        VALIDATE_ONLY_REQUEST_HAS_PAGE_TOKEN: int
        CANNOT_RETURN_SUMMARY_ROW_FOR_REQUEST_WITHOUT_METRICS: int
        CANNOT_RETURN_SUMMARY_ROW_FOR_VALIDATE_ONLY_REQUESTS: int
        INCONSISTENT_RETURN_SUMMARY_ROW_VALUE: int
        TOTAL_RESULTS_COUNT_NOT_ORIGINALLY_REQUESTED: int
        RPC_DEADLINE_TOO_SHORT: int



from typing import Any

import proto

__protobuf__: Any

class SettingErrorEnum(proto.Message):
    class SettingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SETTING_TYPE_IS_NOT_AVAILABLE: int
        SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN: int
        TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP: int
        TARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL: int
        TARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP: int
        DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT: int
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME: int
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME: int
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE: int
        TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN: int
        SETTING_VALUE_NOT_COMPATIBLE_WITH_CAMPAIGN: int



from typing import Any

import proto

__protobuf__: Any

class UserListRuleTypeEnum(proto.Message):
    class UserListRuleType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AND_OF_ORS: int
        OR_OF_ANDS: int



from typing import Any

import proto

__protobuf__: Any

class AdGroupTypeEnum(proto.Message):
    class AdGroupType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SEARCH_STANDARD: int
        DISPLAY_STANDARD: int
        SHOPPING_PRODUCT_ADS: int
        HOTEL_ADS: int
        SHOPPING_SMART_ADS: int
        VIDEO_BUMPER: int
        VIDEO_TRUE_VIEW_IN_STREAM: int
        VIDEO_TRUE_VIEW_IN_DISPLAY: int
        VIDEO_NON_SKIPPABLE_IN_STREAM: int
        VIDEO_OUTSTREAM: int
        SEARCH_DYNAMIC_ADS: int
        SHOPPING_COMPARISON_LISTING_ADS: int
        PROMOTED_HOTEL_ADS: int
        VIDEO_RESPONSIVE: int
        VIDEO_EFFICIENT_REACH: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import criteria as criteria
from google.ads.googleads.v8.enums.types import (
    feed_item_target_device as feed_item_target_device,
    feed_item_target_status as feed_item_target_status,
)

__protobuf__: Any

class FeedItemTarget(proto.Message):
    resource_name: Any
    feed_item: Any
    feed_item_target_type: Any
    feed_item_target_id: Any
    status: Any
    campaign: Any
    ad_group: Any
    keyword: Any
    geo_target_constant: Any
    device: Any
    ad_schedule: Any



from typing import Any

import proto

__protobuf__: Any

class PaymentsAccount(proto.Message):
    resource_name: Any
    payments_account_id: Any
    name: Any
    currency_code: Any
    payments_profile_id: Any
    secondary_payments_profile_id: Any
    paying_manager_customer: Any



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    access_invitation_status as access_invitation_status,
)

__protobuf__: Any

class CustomerUserAccessInvitation(proto.Message):
    resource_name: Any
    invitation_id: Any
    access_role: Any
    email_address: Any
    creation_date_time: Any
    invitation_status: Any



from typing import Any

import proto

__protobuf__: Any

class CampaignServingStatusEnum(proto.Message):
    class CampaignServingStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SERVING: int
        NONE: int
        ENDED: int
        PENDING: int
        SUSPENDED: int



from typing import Any

import proto

__protobuf__: Any

class ProductCustomAttributeIndexEnum(proto.Message):
    class ProductCustomAttributeIndex(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INDEX0: int
        INDEX1: int
        INDEX2: int
        INDEX3: int
        INDEX4: int



from typing import Any

import proto

__protobuf__: Any

class PriceExtensionTypeEnum(proto.Message):
    class PriceExtensionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BRANDS: int
        EVENTS: int
        LOCATIONS: int
        NEIGHBORHOODS: int
        PRODUCT_CATEGORIES: int
        PRODUCT_TIERS: int
        SERVICES: int
        SERVICE_CATEGORIES: int
        SERVICE_TIERS: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import (
    bidding as bidding,
    custom_parameter as custom_parameter,
    frequency_cap as frequency_cap,
)
from google.ads.googleads.v7.enums.types import (
    app_campaign_app_store as app_campaign_app_store,
    app_campaign_bidding_strategy_goal_type as app_campaign_bidding_strategy_goal_type,
    asset_field_type as asset_field_type,
    brand_safety_suitability as brand_safety_suitability,
    campaign_experiment_type as campaign_experiment_type,
    campaign_serving_status as campaign_serving_status,
    campaign_status as campaign_status,
    optimization_goal_type as optimization_goal_type,
)

__protobuf__: Any

class Campaign(proto.Message):
    class NetworkSettings(proto.Message):
        target_google_search: Any
        target_search_network: Any
        target_content_network: Any
        target_partner_search_network: Any
    class HotelSettingInfo(proto.Message):
        hotel_center_id: Any
    class LocalCampaignSetting(proto.Message):
        location_source_type: Any
    class DynamicSearchAdsSetting(proto.Message):
        domain_name: Any
        language_code: Any
        use_supplied_urls_only: Any
        feeds: Any
    class TrackingSetting(proto.Message):
        tracking_url: Any
    class VanityPharma(proto.Message):
        vanity_pharma_display_url_mode: Any
        vanity_pharma_text: Any
    class ShoppingSetting(proto.Message):
        merchant_id: Any
        sales_country: Any
        campaign_priority: Any
        enable_local: Any
    class OptimizationGoalSetting(proto.Message):
        optimization_goal_types: Any
    class GeoTargetTypeSetting(proto.Message):
        positive_geo_target_type: Any
        negative_geo_target_type: Any
    class SelectiveOptimization(proto.Message):
        conversion_actions: Any
    class AppCampaignSetting(proto.Message):
        bidding_strategy_goal_type: Any
        app_id: Any
        app_store: Any
    resource_name: Any
    id: Any
    name: Any
    status: Any
    serving_status: Any
    ad_serving_optimization_status: Any
    advertising_channel_type: Any
    advertising_channel_sub_type: Any
    tracking_url_template: Any
    url_custom_parameters: Any
    real_time_bidding_setting: Any
    network_settings: Any
    hotel_setting: Any
    dynamic_search_ads_setting: Any
    shopping_setting: Any
    targeting_setting: Any
    geo_target_type_setting: Any
    local_campaign_setting: Any
    app_campaign_setting: Any
    labels: Any
    experiment_type: Any
    base_campaign: Any
    campaign_budget: Any
    bidding_strategy_type: Any
    start_date: Any
    end_date: Any
    final_url_suffix: Any
    frequency_caps: Any
    video_brand_safety_suitability: Any
    vanity_pharma: Any
    selective_optimization: Any
    optimization_goal_setting: Any
    tracking_setting: Any
    payment_mode: Any
    optimization_score: Any
    excluded_parent_asset_field_types: Any
    bidding_strategy: Any
    commission: Any
    manual_cpc: Any
    manual_cpm: Any
    manual_cpv: Any
    maximize_conversions: Any
    maximize_conversion_value: Any
    target_cpa: Any
    target_impression_share: Any
    target_roas: Any
    target_spend: Any
    percent_cpc: Any
    target_cpm: Any



from typing import Any

import proto

__protobuf__: Any

class PlacementTypeEnum(proto.Message):
    class PlacementType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        WEBSITE: int
        MOBILE_APP_CATEGORY: int
        MOBILE_APPLICATION: int
        YOUTUBE_VIDEO: int
        YOUTUBE_CHANNEL: int



from typing import Any

import proto

__protobuf__: Any

class ProximityRadiusUnitsEnum(proto.Message):
    class ProximityRadiusUnits(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MILES: int
        KILOMETERS: int



from .base import (
    DisplayKeywordViewServiceTransport as DisplayKeywordViewServiceTransport,
)
from .grpc import (
    DisplayKeywordViewServiceGrpcTransport as DisplayKeywordViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class ExternalConversionSourceEnum(proto.Message):
    class ExternalConversionSource(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        WEBPAGE: int
        ANALYTICS: int
        UPLOAD: int
        AD_CALL_METRICS: int
        WEBSITE_CALL_METRICS: int
        STORE_VISITS: int
        ANDROID_IN_APP: int
        IOS_IN_APP: int
        IOS_FIRST_OPEN: int
        APP_UNSPECIFIED: int
        ANDROID_FIRST_OPEN: int
        UPLOAD_CALLS: int
        FIREBASE: int
        CLICK_TO_CALL: int
        SALESFORCE: int
        STORE_SALES_CRM: int
        STORE_SALES_PAYMENT_NETWORK: int
        GOOGLE_PLAY: int
        THIRD_PARTY_APP_ANALYTICS: int
        GOOGLE_ATTRIBUTION: int
        STORE_SALES_DIRECT_UPLOAD: int
        STORE_SALES: int
        SEARCH_ADS_360: int
        GOOGLE_HOSTED: int
        FLOODLIGHT: int
        ANALYTICS_SEARCH_ADS_360: int
        FIREBASE_SEARCH_ADS_360: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import (
    criteria as criteria,
    custom_parameter as custom_parameter,
)
from google.ads.googleads.v8.enums.types import (
    ad_group_criterion_approval_status as ad_group_criterion_approval_status,
    ad_group_criterion_status as ad_group_criterion_status,
    bidding_source as bidding_source,
    criterion_system_serving_status as criterion_system_serving_status,
    criterion_type as criterion_type,
    quality_score_bucket as quality_score_bucket,
)

__protobuf__: Any

class AdGroupCriterion(proto.Message):
    class QualityInfo(proto.Message):
        quality_score: Any
        creative_quality_score: Any
        post_click_quality_score: Any
        search_predicted_ctr: Any
    class PositionEstimates(proto.Message):
        first_page_cpc_micros: Any
        first_position_cpc_micros: Any
        top_of_page_cpc_micros: Any
        estimated_add_clicks_at_first_position_cpc: Any
        estimated_add_cost_at_first_position_cpc: Any
    resource_name: Any
    criterion_id: Any
    display_name: Any
    status: Any
    quality_info: Any
    ad_group: Any
    type_: Any
    negative: Any
    system_serving_status: Any
    approval_status: Any
    disapproval_reasons: Any
    labels: Any
    bid_modifier: Any
    cpc_bid_micros: Any
    cpm_bid_micros: Any
    cpv_bid_micros: Any
    percent_cpc_bid_micros: Any
    effective_cpc_bid_micros: Any
    effective_cpm_bid_micros: Any
    effective_cpv_bid_micros: Any
    effective_percent_cpc_bid_micros: Any
    effective_cpc_bid_source: Any
    effective_cpm_bid_source: Any
    effective_cpv_bid_source: Any
    effective_percent_cpc_bid_source: Any
    position_estimates: Any
    final_urls: Any
    final_mobile_urls: Any
    final_url_suffix: Any
    tracking_url_template: Any
    url_custom_parameters: Any
    keyword: Any
    placement: Any
    mobile_app_category: Any
    mobile_application: Any
    listing_group: Any
    age_range: Any
    gender: Any
    income_range: Any
    parental_status: Any
    user_list: Any
    youtube_video: Any
    youtube_channel: Any
    topic: Any
    user_interest: Any
    webpage: Any
    app_payment_model: Any
    custom_affinity: Any
    custom_intent: Any
    custom_audience: Any
    combined_audience: Any



from typing import Any

import proto

__protobuf__: Any

class CriterionTypeEnum(proto.Message):
    class CriterionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        KEYWORD: int
        PLACEMENT: int
        MOBILE_APP_CATEGORY: int
        MOBILE_APPLICATION: int
        DEVICE: int
        LOCATION: int
        LISTING_GROUP: int
        AD_SCHEDULE: int
        AGE_RANGE: int
        GENDER: int
        INCOME_RANGE: int
        PARENTAL_STATUS: int
        YOUTUBE_VIDEO: int
        YOUTUBE_CHANNEL: int
        USER_LIST: int
        PROXIMITY: int
        TOPIC: int
        LISTING_SCOPE: int
        LANGUAGE: int
        IP_BLOCK: int
        CONTENT_LABEL: int
        CARRIER: int
        USER_INTEREST: int
        WEBPAGE: int
        OPERATING_SYSTEM_VERSION: int
        APP_PAYMENT_MODEL: int
        MOBILE_DEVICE: int
        CUSTOM_AFFINITY: int
        CUSTOM_INTENT: int
        LOCATION_GROUP: int
        CUSTOM_AUDIENCE: int
        COMBINED_AUDIENCE: int
        KEYWORD_THEME: int



from typing import Any

import proto

__protobuf__: Any

class ChangeClientTypeEnum(proto.Message):
    class ChangeClientType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        GOOGLE_ADS_WEB_CLIENT: int
        GOOGLE_ADS_AUTOMATED_RULE: int
        GOOGLE_ADS_SCRIPTS: int
        GOOGLE_ADS_BULK_UPLOAD: int
        GOOGLE_ADS_API: int
        GOOGLE_ADS_EDITOR: int
        GOOGLE_ADS_MOBILE_APP: int
        GOOGLE_ADS_RECOMMENDATIONS: int
        SEARCH_ADS_360_SYNC: int
        SEARCH_ADS_360_POST: int
        INTERNAL_TOOL: int
        OTHER: int



from typing import Any

import proto

__protobuf__: Any

class BudgetTypeEnum(proto.Message):
    class BudgetType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        STANDARD: int
        HOTEL_ADS_COMMISSION: int
        FIXED_CPA: int
        SMART_CAMPAIGN: int



from typing import Any

import proto

__protobuf__: Any

class FeedItemQualityApprovalStatusEnum(proto.Message):
    class FeedItemQualityApprovalStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        APPROVED: int
        DISAPPROVED: int



from .base import (
    MobileDeviceConstantServiceTransport as MobileDeviceConstantServiceTransport,
)
from .grpc import (
    MobileDeviceConstantServiceGrpcTransport as MobileDeviceConstantServiceGrpcTransport,
)



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    interaction_event_type as interaction_event_type,
    quality_score_bucket as quality_score_bucket,
)

__protobuf__: Any

class Metrics(proto.Message):
    absolute_top_impression_percentage: Any
    active_view_cpm: Any
    active_view_ctr: Any
    active_view_impressions: Any
    active_view_measurability: Any
    active_view_measurable_cost_micros: Any
    active_view_measurable_impressions: Any
    active_view_viewability: Any
    all_conversions_from_interactions_rate: Any
    all_conversions_value: Any
    all_conversions_value_by_conversion_date: Any
    all_conversions: Any
    all_conversions_by_conversion_date: Any
    all_conversions_value_per_cost: Any
    all_conversions_from_click_to_call: Any
    all_conversions_from_directions: Any
    all_conversions_from_interactions_value_per_interaction: Any
    all_conversions_from_menu: Any
    all_conversions_from_order: Any
    all_conversions_from_other_engagement: Any
    all_conversions_from_store_visit: Any
    all_conversions_from_store_website: Any
    average_cost: Any
    average_cpc: Any
    average_cpe: Any
    average_cpm: Any
    average_cpv: Any
    average_page_views: Any
    average_time_on_site: Any
    benchmark_average_max_cpc: Any
    benchmark_ctr: Any
    bounce_rate: Any
    clicks: Any
    combined_clicks: Any
    combined_clicks_per_query: Any
    combined_queries: Any
    content_budget_lost_impression_share: Any
    content_impression_share: Any
    conversion_last_received_request_date_time: Any
    conversion_last_conversion_date: Any
    content_rank_lost_impression_share: Any
    conversions_from_interactions_rate: Any
    conversions_value: Any
    conversions_value_by_conversion_date: Any
    conversions_value_per_cost: Any
    conversions_from_interactions_value_per_interaction: Any
    conversions: Any
    conversions_by_conversion_date: Any
    cost_micros: Any
    cost_per_all_conversions: Any
    cost_per_conversion: Any
    cost_per_current_model_attributed_conversion: Any
    cross_device_conversions: Any
    ctr: Any
    current_model_attributed_conversions: Any
    current_model_attributed_conversions_from_interactions_rate: Any
    current_model_attributed_conversions_from_interactions_value_per_interaction: Any
    current_model_attributed_conversions_value: Any
    current_model_attributed_conversions_value_per_cost: Any
    engagement_rate: Any
    engagements: Any
    hotel_average_lead_value_micros: Any
    hotel_price_difference_percentage: Any
    hotel_eligible_impressions: Any
    historical_creative_quality_score: Any
    historical_landing_page_quality_score: Any
    historical_quality_score: Any
    historical_search_predicted_ctr: Any
    gmail_forwards: Any
    gmail_saves: Any
    gmail_secondary_clicks: Any
    impressions_from_store_reach: Any
    impressions: Any
    interaction_rate: Any
    interactions: Any
    interaction_event_types: Any
    invalid_click_rate: Any
    invalid_clicks: Any
    message_chats: Any
    message_impressions: Any
    message_chat_rate: Any
    mobile_friendly_clicks_percentage: Any
    optimization_score_uplift: Any
    optimization_score_url: Any
    organic_clicks: Any
    organic_clicks_per_query: Any
    organic_impressions: Any
    organic_impressions_per_query: Any
    organic_queries: Any
    percent_new_visitors: Any
    phone_calls: Any
    phone_impressions: Any
    phone_through_rate: Any
    relative_ctr: Any
    search_absolute_top_impression_share: Any
    search_budget_lost_absolute_top_impression_share: Any
    search_budget_lost_impression_share: Any
    search_budget_lost_top_impression_share: Any
    search_click_share: Any
    search_exact_match_impression_share: Any
    search_impression_share: Any
    search_rank_lost_absolute_top_impression_share: Any
    search_rank_lost_impression_share: Any
    search_rank_lost_top_impression_share: Any
    search_top_impression_share: Any
    speed_score: Any
    top_impression_percentage: Any
    valid_accelerated_mobile_pages_clicks_percentage: Any
    value_per_all_conversions: Any
    value_per_all_conversions_by_conversion_date: Any
    value_per_conversion: Any
    value_per_conversions_by_conversion_date: Any
    value_per_current_model_attributed_conversion: Any
    video_quartile_p100_rate: Any
    video_quartile_p25_rate: Any
    video_quartile_p50_rate: Any
    video_quartile_p75_rate: Any
    video_view_rate: Any
    video_views: Any
    view_through_conversions: Any
    sk_ad_network_conversions: Any



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    custom_audience_member_type as custom_audience_member_type,
    custom_audience_status as custom_audience_status,
    custom_audience_type as custom_audience_type,
)

__protobuf__: Any

class CustomAudience(proto.Message):
    resource_name: Any
    id: Any
    status: Any
    name: Any
    type_: Any
    description: Any
    members: Any

class CustomAudienceMember(proto.Message):
    member_type: Any
    keyword: Any
    url: Any
    place_category: Any
    app: Any



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    account_budget_proposal_type as account_budget_proposal_type,
    account_budget_status as account_budget_status,
    time_type as time_type,
)

__protobuf__: Any

class AccountBudget(proto.Message):
    class PendingAccountBudgetProposal(proto.Message):
        account_budget_proposal: Any
        proposal_type: Any
        name: Any
        start_date_time: Any
        purchase_order_number: Any
        notes: Any
        creation_date_time: Any
        end_date_time: Any
        end_time_type: Any
        spending_limit_micros: Any
        spending_limit_type: Any
    resource_name: Any
    id: Any
    billing_setup: Any
    status: Any
    name: Any
    proposed_start_date_time: Any
    approved_start_date_time: Any
    total_adjustments_micros: Any
    amount_served_micros: Any
    purchase_order_number: Any
    notes: Any
    pending_proposal: Any
    proposed_end_date_time: Any
    proposed_end_time_type: Any
    approved_end_date_time: Any
    approved_end_time_type: Any
    proposed_spending_limit_micros: Any
    proposed_spending_limit_type: Any
    approved_spending_limit_micros: Any
    approved_spending_limit_type: Any
    adjusted_spending_limit_micros: Any
    adjusted_spending_limit_type: Any



from typing import Any, Dict, Optional, Sequence, Tuple, Type, Union

from google.api_core import (
    client_options as client_options_lib,
    gapic_v1,
    retry as retries,
)
from google.auth import credentials as ga_credentials

from google.ads.googleads.v8.resources.types import billing_setup
from google.ads.googleads.v8.services.types import billing_setup_service

from .transports.base import BillingSetupServiceTransport

class BillingSetupServiceClientMeta(type):
    def get_transport_class(
        cls, label: str = ...
    ) -> Type[BillingSetupServiceTransport]: ...

class BillingSetupServiceClient(metaclass=BillingSetupServiceClientMeta):
    DEFAULT_ENDPOINT: str
    DEFAULT_MTLS_ENDPOINT: Any
    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs): ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs): ...
    from_service_account_json: Any
    @property
    def transport(self) -> BillingSetupServiceTransport: ...
    @staticmethod
    def billing_setup_path(customer_id: str, billing_setup_id: str) -> str: ...
    @staticmethod
    def parse_billing_setup_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def payments_account_path(customer_id: str, payments_account_id: str) -> str: ...
    @staticmethod
    def parse_payments_account_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_billing_account_path(billing_account: str) -> str: ...
    @staticmethod
    def parse_common_billing_account_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_folder_path(folder: str) -> str: ...
    @staticmethod
    def parse_common_folder_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_organization_path(organization: str) -> str: ...
    @staticmethod
    def parse_common_organization_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_project_path(project: str) -> str: ...
    @staticmethod
    def parse_common_project_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_location_path(project: str, location: str) -> str: ...
    @staticmethod
    def parse_common_location_path(path: str) -> Dict[str, str]: ...
    def __init__(
        self,
        *,
        credentials: Optional[ga_credentials.Credentials] = ...,
        transport: Union[str, BillingSetupServiceTransport, None] = ...,
        client_options: Optional[client_options_lib.ClientOptions] = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    def get_billing_setup(
        self,
        request: billing_setup_service.GetBillingSetupRequest = ...,
        *,
        resource_name: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> billing_setup.BillingSetup: ...
    def mutate_billing_setup(
        self,
        request: billing_setup_service.MutateBillingSetupRequest = ...,
        *,
        customer_id: str = ...,
        operation: billing_setup_service.BillingSetupOperation = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> billing_setup_service.MutateBillingSetupResponse: ...



from .base import (
    ProductBiddingCategoryConstantServiceTransport as ProductBiddingCategoryConstantServiceTransport,
)
from .grpc import (
    ProductBiddingCategoryConstantServiceGrpcTransport as ProductBiddingCategoryConstantServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class TrackingCodePageFormatEnum(proto.Message):
    class TrackingCodePageFormat(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        HTML: int
        AMP: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    advertising_channel_type as advertising_channel_type,
    device as device,
    seasonality_event_scope as seasonality_event_scope,
    seasonality_event_status as seasonality_event_status,
)

__protobuf__: Any

class BiddingSeasonalityAdjustment(proto.Message):
    resource_name: Any
    seasonality_adjustment_id: Any
    scope: Any
    status: Any
    start_date_time: Any
    end_date_time: Any
    name: Any
    description: Any
    devices: Any
    conversion_rate_modifier: Any
    campaigns: Any
    advertising_channel_types: Any



from typing import Any

import proto

__protobuf__: Any

class DsaPageFeedCriterionFieldEnum(proto.Message):
    class DsaPageFeedCriterionField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PAGE_URL: int
        LABEL: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    campaign_shared_set_status as campaign_shared_set_status,
)

__protobuf__: Any

class CampaignSharedSet(proto.Message):
    resource_name: Any
    campaign: Any
    shared_set: Any
    status: Any



from typing import Any

import proto

__protobuf__: Any

class PartialFailureErrorEnum(proto.Message):
    class PartialFailureError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PARTIAL_FAILURE_MODE_REQUIRED: int



from typing import Any

import proto

__protobuf__: Any

class FrequencyCapTimeUnitEnum(proto.Message):
    class FrequencyCapTimeUnit(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DAY: int
        WEEK: int
        MONTH: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    budget_delivery_method as budget_delivery_method,
    budget_period as budget_period,
    budget_status as budget_status,
    budget_type as budget_type,
)

__protobuf__: Any

class CampaignBudget(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    amount_micros: Any
    total_amount_micros: Any
    status: Any
    delivery_method: Any
    explicitly_shared: Any
    reference_count: Any
    has_recommended_budget: Any
    recommended_budget_amount_micros: Any
    period: Any
    recommended_budget_estimated_change_weekly_clicks: Any
    recommended_budget_estimated_change_weekly_cost_micros: Any
    recommended_budget_estimated_change_weekly_interactions: Any
    recommended_budget_estimated_change_weekly_views: Any
    type_: Any



from typing import Any

import proto

__protobuf__: Any

class RangeErrorEnum(proto.Message):
    class RangeError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        TOO_LOW: int
        TOO_HIGH: int



from typing import Any

import proto

__protobuf__: Any

class AccountLinkErrorEnum(proto.Message):
    class AccountLinkError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_STATUS: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import (
    criterion_category_availability as criterion_category_availability,
)

__protobuf__: Any

class DetailedDemographic(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    parent: Any
    launched_to_all: Any
    availabilities: Any



from typing import Any

import proto

from google.ads.googleads.v7.common.types import dates as dates
from google.ads.googleads.v7.enums.types import (
    keyword_plan_aggregate_metric_type as keyword_plan_aggregate_metric_type,
    keyword_plan_competition_level as keyword_plan_competition_level,
    keyword_plan_concept_group_type as keyword_plan_concept_group_type,
    month_of_year as month_of_year,
)

__protobuf__: Any

class KeywordPlanHistoricalMetrics(proto.Message):
    avg_monthly_searches: Any
    monthly_search_volumes: Any
    competition: Any
    competition_index: Any
    low_top_of_page_bid_micros: Any
    high_top_of_page_bid_micros: Any

class HistoricalMetricsOptions(proto.Message):
    year_month_range: Any

class MonthlySearchVolume(proto.Message):
    year: Any
    month: Any
    monthly_searches: Any

class KeywordPlanAggregateMetrics(proto.Message):
    aggregate_metric_types: Any

class KeywordPlanAggregateMetricResults(proto.Message):
    device_searches: Any

class KeywordPlanDeviceSearches(proto.Message):
    device: Any
    search_count: Any

class KeywordAnnotations(proto.Message):
    concepts: Any

class KeywordConcept(proto.Message):
    name: Any
    concept_group: Any

class ConceptGroup(proto.Message):
    name: Any
    type_: Any



from typing import Any

import proto

__protobuf__: Any

class DateErrorEnum(proto.Message):
    class DateError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_FIELD_VALUES_IN_DATE: int
        INVALID_FIELD_VALUES_IN_DATE_TIME: int
        INVALID_STRING_DATE: int
        INVALID_STRING_DATE_TIME_MICROS: int
        INVALID_STRING_DATE_TIME_SECONDS: int
        INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET: int
        EARLIER_THAN_MINIMUM_DATE: int
        LATER_THAN_MAXIMUM_DATE: int
        DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE: int
        DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL: int



from typing import Any

import proto

__protobuf__: Any

class AdCustomizerPlaceholderFieldEnum(proto.Message):
    class AdCustomizerPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INTEGER: int
        PRICE: int
        DATE: int
        STRING: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    feed_link_status as feed_link_status,
    placeholder_type as placeholder_type,
)

__protobuf__: Any

class CampaignFeed(proto.Message):
    resource_name: Any
    feed: Any
    campaign: Any
    placeholder_types: Any
    matching_function: Any
    status: Any



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import label_status as label_status

__protobuf__: Any

class Label(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    status: Any
    text_label: Any



from typing import Any

import proto

from google.ads.googleads.v7.common.types import (
    criterion_category_availability as criterion_category_availability,
)
from google.ads.googleads.v7.enums.types import (
    user_interest_taxonomy_type as user_interest_taxonomy_type,
)

__protobuf__: Any

class UserInterest(proto.Message):
    resource_name: Any
    taxonomy_type: Any
    user_interest_id: Any
    name: Any
    user_interest_parent: Any
    launched_to_all: Any
    availabilities: Any



from .base import (
    GroupPlacementViewServiceTransport as GroupPlacementViewServiceTransport,
)
from .grpc import (
    GroupPlacementViewServiceGrpcTransport as GroupPlacementViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class LeadFormCallToActionTypeEnum(proto.Message):
    class LeadFormCallToActionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LEARN_MORE: int
        GET_QUOTE: int
        APPLY_NOW: int
        SIGN_UP: int
        CONTACT_US: int
        SUBSCRIBE: int
        DOWNLOAD: int
        BOOK_NOW: int
        GET_OFFER: int
        REGISTER: int
        GET_INFO: int
        REQUEST_DEMO: int
        JOIN_NOW: int
        GET_STARTED: int



from typing import Any

import proto

__protobuf__: Any

class CriterionSystemServingStatusEnum(proto.Message):
    class CriterionSystemServingStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ELIGIBLE: int
        RARELY_SERVED: int



from typing import Any

import proto

from google.ads.googleads.v8.resources.types import (
    keyword_theme_constant as keyword_theme_constant,
)

__protobuf__: Any

class GetKeywordThemeConstantRequest(proto.Message):
    resource_name: Any

class SuggestKeywordThemeConstantsRequest(proto.Message):
    query_text: Any
    country_code: Any
    language_code: Any

class SuggestKeywordThemeConstantsResponse(proto.Message):
    keyword_theme_constants: Any



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanKeywordAnnotationEnum(proto.Message):
    class KeywordPlanKeywordAnnotation(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        KEYWORD_CONCEPT: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    search_term_targeting_status as search_term_targeting_status,
)

__protobuf__: Any

class SearchTermView(proto.Message):
    resource_name: Any
    search_term: Any
    ad_group: Any
    status: Any



from typing import Any

import proto

__protobuf__: Any

class ValueRuleSetDimensionEnum(proto.Message):
    class ValueRuleSetDimension(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        GEO_LOCATION: int
        DEVICE: int
        AUDIENCE: int



from typing import Any

import proto

__protobuf__: Any

class CampaignSharedSetErrorEnum(proto.Message):
    class CampaignSharedSetError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SHARED_SET_ACCESS_DENIED: int



from typing import Any

import proto

__protobuf__: Any

class SharedSetErrorEnum(proto.Message):
    class SharedSetError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE: int
        DUPLICATE_NAME: int
        SHARED_SET_REMOVED: int
        SHARED_SET_IN_USE: int



from typing import Any

import proto

__protobuf__: Any

class AccessReasonEnum(proto.Message):
    class AccessReason(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        OWNED: int
        SHARED: int
        LICENSED: int
        SUBSCRIBED: int
        AFFILIATED: int



from .base import (
    ManagedPlacementViewServiceTransport as ManagedPlacementViewServiceTransport,
)
from .grpc import (
    ManagedPlacementViewServiceGrpcTransport as ManagedPlacementViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class MerchantCenterLinkStatusEnum(proto.Message):
    class MerchantCenterLinkStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ENABLED: int
        PENDING: int



from typing import Any

import proto

__protobuf__: Any

class PromotionPlaceholderFieldEnum(proto.Message):
    class PromotionPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PROMOTION_TARGET: int
        DISCOUNT_MODIFIER: int
        PERCENT_OFF: int
        MONEY_AMOUNT_OFF: int
        PROMOTION_CODE: int
        ORDERS_OVER_AMOUNT: int
        PROMOTION_START: int
        PROMOTION_END: int
        OCCASION: int
        FINAL_URLS: int
        FINAL_MOBILE_URLS: int
        TRACKING_URL: int
        LANGUAGE: int
        FINAL_URL_SUFFIX: int



from typing import Any

import proto

__protobuf__: Any

class CallTypeEnum(proto.Message):
    class CallType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MANUALLY_DIALED: int
        HIGH_END_MOBILE_SEARCH: int



from typing import Any

import proto

__protobuf__: Any

class ReachPlanAgeRangeEnum(proto.Message):
    class ReachPlanAgeRange(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AGE_RANGE_18_24: int
        AGE_RANGE_18_34: int
        AGE_RANGE_18_44: int
        AGE_RANGE_18_49: int
        AGE_RANGE_18_54: int
        AGE_RANGE_18_64: int
        AGE_RANGE_18_65_UP: int
        AGE_RANGE_21_34: int
        AGE_RANGE_25_34: int
        AGE_RANGE_25_44: int
        AGE_RANGE_25_49: int
        AGE_RANGE_25_54: int
        AGE_RANGE_25_64: int
        AGE_RANGE_25_65_UP: int
        AGE_RANGE_35_44: int
        AGE_RANGE_35_49: int
        AGE_RANGE_35_54: int
        AGE_RANGE_35_64: int
        AGE_RANGE_35_65_UP: int
        AGE_RANGE_45_54: int
        AGE_RANGE_45_64: int
        AGE_RANGE_45_65_UP: int
        AGE_RANGE_50_65_UP: int
        AGE_RANGE_55_64: int
        AGE_RANGE_55_65_UP: int
        AGE_RANGE_65_UP: int



from typing import Any

import proto

__protobuf__: Any

class CustomInterestTypeEnum(proto.Message):
    class CustomInterestType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CUSTOM_AFFINITY: int
        CUSTOM_INTENT: int



from typing import Any

import proto

__protobuf__: Any

class MessagePlaceholderFieldEnum(proto.Message):
    class MessagePlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BUSINESS_NAME: int
        COUNTRY_CODE: int
        PHONE_NUMBER: int
        MESSAGE_EXTENSION_TEXT: int
        MESSAGE_TEXT: int



from typing import Any

import proto

__protobuf__: Any

class RealEstatePlaceholderFieldEnum(proto.Message):
    class RealEstatePlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LISTING_ID: int
        LISTING_NAME: int
        CITY_NAME: int
        DESCRIPTION: int
        ADDRESS: int
        PRICE: int
        FORMATTED_PRICE: int
        IMAGE_URL: int
        PROPERTY_TYPE: int
        LISTING_TYPE: int
        CONTEXTUAL_KEYWORDS: int
        FINAL_URLS: int
        FINAL_MOBILE_URLS: int
        TRACKING_URL: int
        ANDROID_APP_LINK: int
        SIMILAR_LISTING_IDS: int
        IOS_APP_LINK: int
        IOS_APP_STORE_ID: int



from typing import Any

import proto

__protobuf__: Any

class DynamicSearchAdsSearchTermView(proto.Message):
    resource_name: Any
    search_term: Any
    headline: Any
    landing_page: Any
    page_url: Any
    has_negative_keyword: Any
    has_matching_keyword: Any
    has_negative_url: Any



from typing import Any

import proto

from google.ads.googleads.v7.common.types import bidding as bidding
from google.ads.googleads.v7.enums.types import (
    bidding_strategy_status as bidding_strategy_status,
    bidding_strategy_type as bidding_strategy_type,
)

__protobuf__: Any

class BiddingStrategy(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    status: Any
    type_: Any
    effective_currency_code: Any
    campaign_count: Any
    non_removed_campaign_count: Any
    enhanced_cpc: Any
    maximize_conversion_value: Any
    maximize_conversions: Any
    target_cpa: Any
    target_impression_share: Any
    target_roas: Any
    target_spend: Any



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import (
    keyword_plan_ad_group as keyword_plan_ad_group,
)

__protobuf__: Any

class GetKeywordPlanAdGroupRequest(proto.Message):
    resource_name: Any

class MutateKeywordPlanAdGroupsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any

class KeywordPlanAdGroupOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any
    remove: Any

class MutateKeywordPlanAdGroupsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateKeywordPlanAdGroupResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanNetworkEnum(proto.Message):
    class KeywordPlanNetwork(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        GOOGLE_SEARCH: int
        GOOGLE_SEARCH_AND_PARTNERS: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import (
    ad_type_infos as ad_type_infos,
    criteria as criteria,
)

__protobuf__: Any

class SuggestSmartCampaignBudgetOptionsRequest(proto.Message):
    customer_id: Any
    campaign: Any
    suggestion_info: Any

class SmartCampaignSuggestionInfo(proto.Message):
    class LocationList(proto.Message):
        locations: Any
    class BusinessContext(proto.Message):
        business_name: Any
    final_url: Any
    language_code: Any
    ad_schedules: Any
    keyword_themes: Any
    business_context: Any
    business_location_id: Any
    location_list: Any
    proximity: Any

class SuggestSmartCampaignBudgetOptionsResponse(proto.Message):
    class Metrics(proto.Message):
        min_daily_clicks: Any
        max_daily_clicks: Any
    class BudgetOption(proto.Message):
        daily_amount_micros: Any
        metrics: Any
    low: Any
    recommended: Any
    high: Any

class SuggestSmartCampaignAdRequest(proto.Message):
    customer_id: Any
    suggestion_info: Any

class SuggestSmartCampaignAdResponse(proto.Message):
    ad_info: Any



from typing import Any

import proto

__protobuf__: Any

class PlaceholderTypeEnum(proto.Message):
    class PlaceholderType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SITELINK: int
        CALL: int
        APP: int
        LOCATION: int
        AFFILIATE_LOCATION: int
        CALLOUT: int
        STRUCTURED_SNIPPET: int
        MESSAGE: int
        PRICE: int
        PROMOTION: int
        AD_CUSTOMIZER: int
        DYNAMIC_EDUCATION: int
        DYNAMIC_FLIGHT: int
        DYNAMIC_CUSTOM: int
        DYNAMIC_HOTEL: int
        DYNAMIC_REAL_ESTATE: int
        DYNAMIC_TRAVEL: int
        DYNAMIC_LOCAL: int
        DYNAMIC_JOB: int
        IMAGE: int



from typing import Any

import proto

__protobuf__: Any

class UserDataErrorEnum(proto.Message):
    class UserDataError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        OPERATIONS_FOR_CUSTOMER_MATCH_NOT_ALLOWED: int
        TOO_MANY_USER_IDENTIFIERS: int
        USER_LIST_NOT_APPLICABLE: int



from typing import Any

import proto

__protobuf__: Any

class ReachPlanNetworkEnum(proto.Message):
    class ReachPlanNetwork(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        YOUTUBE: int
        GOOGLE_VIDEO_PARTNERS: int
        YOUTUBE_AND_GOOGLE_VIDEO_PARTNERS: int



from typing import Any

import proto

__protobuf__: Any

class UserInterestTaxonomyTypeEnum(proto.Message):
    class UserInterestTaxonomyType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AFFINITY: int
        IN_MARKET: int
        MOBILE_APP_INSTALL_USER: int
        VERTICAL_GEO: int
        NEW_SMART_PHONE_USER: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    campaign_draft_status as campaign_draft_status,
)

__protobuf__: Any

class CampaignDraft(proto.Message):
    resource_name: Any
    draft_id: Any
    base_campaign: Any
    name: Any
    draft_campaign: Any
    status: Any
    has_experiment_running: Any
    long_running_operation: Any



from typing import Any

import proto

__protobuf__: Any

class PolicyReviewStatusEnum(proto.Message):
    class PolicyReviewStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        REVIEW_IN_PROGRESS: int
        REVIEWED: int
        UNDER_APPEAL: int
        ELIGIBLE_MAY_SERVE: int



from typing import Any

import proto

__protobuf__: Any

class FeedItemValidationErrorEnum(proto.Message):
    class FeedItemValidationError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        STRING_TOO_SHORT: int
        STRING_TOO_LONG: int
        VALUE_NOT_SPECIFIED: int
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT: int
        INVALID_PHONE_NUMBER: int
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int
        DISALLOWED_NUMBER_TYPE: int
        VALUE_OUT_OF_RANGE: int
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int
        CUSTOMER_NOT_IN_ALLOWLIST_FOR_CALLTRACKING: int
        INVALID_COUNTRY_CODE: int
        INVALID_APP_ID: int
        MISSING_ATTRIBUTES_FOR_FIELDS: int
        INVALID_TYPE_ID: int
        INVALID_EMAIL_ADDRESS: int
        INVALID_HTTPS_URL: int
        MISSING_DELIVERY_ADDRESS: int
        START_DATE_AFTER_END_DATE: int
        MISSING_FEED_ITEM_START_TIME: int
        MISSING_FEED_ITEM_END_TIME: int
        MISSING_FEED_ITEM_ID: int
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int
        INVALID_REVIEW_EXTENSION_SNIPPET: int
        INVALID_NUMBER_FORMAT: int
        INVALID_DATE_FORMAT: int
        INVALID_PRICE_FORMAT: int
        UNKNOWN_PLACEHOLDER_FIELD: int
        MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE: int
        REVIEW_EXTENSION_SOURCE_INELIGIBLE: int
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET: int
        DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int
        INVALID_FORM_ENCODED_PARAMS: int
        INVALID_URL_PARAMETER_NAME: int
        NO_GEOCODING_RESULT: int
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT: int
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int
        INVALID_PLACEHOLDER_FIELD_ID: int
        INVALID_URL_TAG: int
        LIST_TOO_LONG: int
        INVALID_ATTRIBUTES_COMBINATION: int
        DUPLICATE_VALUES: int
        INVALID_CALL_CONVERSION_ACTION_ID: int
        CANNOT_SET_WITHOUT_FINAL_URLS: int
        APP_ID_DOESNT_EXIST_IN_APP_STORE: int
        INVALID_FINAL_URL: int
        INVALID_TRACKING_URL: int
        INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL: int
        LIST_TOO_SHORT: int
        INVALID_USER_ACTION: int
        INVALID_TYPE_NAME: int
        INVALID_EVENT_CHANGE_STATUS: int
        INVALID_SNIPPETS_HEADER: int
        INVALID_ANDROID_APP_LINK: int
        NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int
        RESERVED_KEYWORD_OTHER: int
        DUPLICATE_OPTION_LABELS: int
        DUPLICATE_OPTION_PREFILLS: int
        UNEQUAL_LIST_LENGTHS: int
        INCONSISTENT_CURRENCY_CODES: int
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS: int
        ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION: int
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS: int
        UNSUPPORTED_VALUE: int
        INVALID_FINAL_MOBILE_URL: int
        INVALID_KEYWORDLESS_AD_RULE_LABEL: int
        VALUE_TRACK_PARAMETER_NOT_SUPPORTED: int
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE: int
        INVALID_IOS_APP_LINK: int
        MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID: int
        PROMOTION_INVALID_TIME: int
        PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF: int
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT: int
        TOO_MANY_DECIMAL_PLACES_SPECIFIED: int
        AD_CUSTOMIZERS_NOT_ALLOWED: int
        INVALID_LANGUAGE_CODE: int
        UNSUPPORTED_LANGUAGE: int
        IF_FUNCTION_NOT_ALLOWED: int
        INVALID_FINAL_URL_SUFFIX: int
        INVALID_TAG_IN_FINAL_URL_SUFFIX: int
        INVALID_FINAL_URL_SUFFIX_FORMAT: int
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int
        ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED: int
        NO_DELIVERY_OPTION_IS_SET: int
        INVALID_CONVERSION_REPORTING_STATE: int
        IMAGE_SIZE_WRONG: int
        EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY: int
        AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY: int
        INVALID_LATITUDE_VALUE: int
        INVALID_LONGITUDE_VALUE: int
        TOO_MANY_LABELS: int
        INVALID_IMAGE_URL: int
        MISSING_LATITUDE_VALUE: int
        MISSING_LONGITUDE_VALUE: int
        ADDRESS_NOT_FOUND: int
        ADDRESS_NOT_TARGETABLE: int
        INVALID_ASSET_ID: int
        INCOMPATIBLE_ASSET_TYPE: int
        IMAGE_ERROR_UNEXPECTED_SIZE: int
        IMAGE_ERROR_ASPECT_RATIO_NOT_ALLOWED: int
        IMAGE_ERROR_FILE_TOO_LARGE: int
        IMAGE_ERROR_FORMAT_NOT_ALLOWED: int
        IMAGE_ERROR_CONSTRAINTS_VIOLATED: int
        IMAGE_ERROR_SERVER_ERROR: int



from typing import Any

import proto

__protobuf__: Any

class PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum(proto.Message):
    class PolicyTopicEvidenceDestinationNotWorkingDnsErrorType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        HOSTNAME_NOT_FOUND: int
        GOOGLE_CRAWLER_DNS_ISSUE: int



from typing import Any

import proto

__protobuf__: Any

class SpendingLimitTypeEnum(proto.Message):
    class SpendingLimitType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INFINITE: int



from typing import Any

import proto

__protobuf__: Any

class PolicyApprovalStatusEnum(proto.Message):
    class PolicyApprovalStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DISAPPROVED: int
        APPROVED_LIMITED: int
        APPROVED: int
        AREA_OF_INTEREST_ONLY: int



from typing import Any

import proto

__protobuf__: Any

class KeywordMatchTypeEnum(proto.Message):
    class KeywordMatchType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EXACT: int
        PHRASE: int
        BROAD: int



from typing import Any

import proto

__protobuf__: Any

class ConversionOrAdjustmentLagBucketEnum(proto.Message):
    class ConversionOrAdjustmentLagBucket(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CONVERSION_LESS_THAN_ONE_DAY: int
        CONVERSION_ONE_TO_TWO_DAYS: int
        CONVERSION_TWO_TO_THREE_DAYS: int
        CONVERSION_THREE_TO_FOUR_DAYS: int
        CONVERSION_FOUR_TO_FIVE_DAYS: int
        CONVERSION_FIVE_TO_SIX_DAYS: int
        CONVERSION_SIX_TO_SEVEN_DAYS: int
        CONVERSION_SEVEN_TO_EIGHT_DAYS: int
        CONVERSION_EIGHT_TO_NINE_DAYS: int
        CONVERSION_NINE_TO_TEN_DAYS: int
        CONVERSION_TEN_TO_ELEVEN_DAYS: int
        CONVERSION_ELEVEN_TO_TWELVE_DAYS: int
        CONVERSION_TWELVE_TO_THIRTEEN_DAYS: int
        CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS: int
        CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS: int
        CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS: int
        CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS: int
        CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS: int
        CONVERSION_SIXTY_TO_NINETY_DAYS: int
        ADJUSTMENT_LESS_THAN_ONE_DAY: int
        ADJUSTMENT_ONE_TO_TWO_DAYS: int
        ADJUSTMENT_TWO_TO_THREE_DAYS: int
        ADJUSTMENT_THREE_TO_FOUR_DAYS: int
        ADJUSTMENT_FOUR_TO_FIVE_DAYS: int
        ADJUSTMENT_FIVE_TO_SIX_DAYS: int
        ADJUSTMENT_SIX_TO_SEVEN_DAYS: int
        ADJUSTMENT_SEVEN_TO_EIGHT_DAYS: int
        ADJUSTMENT_EIGHT_TO_NINE_DAYS: int
        ADJUSTMENT_NINE_TO_TEN_DAYS: int
        ADJUSTMENT_TEN_TO_ELEVEN_DAYS: int
        ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS: int
        ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS: int
        ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS: int
        ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS: int
        ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS: int
        ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS: int
        ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS: int
        ADJUSTMENT_SIXTY_TO_NINETY_DAYS: int
        ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS: int
        CONVERSION_UNKNOWN: int
        ADJUSTMENT_UNKNOWN: int



from typing import Any

import proto

__protobuf__: Any

class ConversionAdjustmentUploadErrorEnum(proto.Message):
    class ConversionAdjustmentUploadError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        TOO_RECENT_CONVERSION_ACTION: int
        INVALID_CONVERSION_ACTION: int
        CONVERSION_ALREADY_RETRACTED: int
        CONVERSION_NOT_FOUND: int
        CONVERSION_EXPIRED: int
        ADJUSTMENT_PRECEDES_CONVERSION: int
        MORE_RECENT_RESTATEMENT_FOUND: int
        TOO_RECENT_CONVERSION: int
        CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE: int
        TOO_MANY_ADJUSTMENTS_IN_REQUEST: int
        TOO_MANY_ADJUSTMENTS: int



from typing import Any

import proto

__protobuf__: Any

class PriceExtensionPriceUnitEnum(proto.Message):
    class PriceExtensionPriceUnit(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PER_HOUR: int
        PER_DAY: int
        PER_WEEK: int
        PER_MONTH: int
        PER_YEAR: int
        PER_NIGHT: int



from typing import Any

import proto

__protobuf__: Any

class PolicyTopicEvidenceDestinationNotWorkingDeviceEnum(proto.Message):
    class PolicyTopicEvidenceDestinationNotWorkingDevice(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DESKTOP: int
        ANDROID: int
        IOS: int



from typing import Any

import proto

__protobuf__: Any

class GeoTargetConstantStatusEnum(proto.Message):
    class GeoTargetConstantStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ENABLED: int
        REMOVAL_PLANNED: int



from typing import Any

import proto

__protobuf__: Any

class FeedItemTargetErrorEnum(proto.Message):
    class FeedItemTargetError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MUST_SET_TARGET_ONEOF_ON_CREATE: int
        FEED_ITEM_TARGET_ALREADY_EXISTS: int
        FEED_ITEM_SCHEDULES_CANNOT_OVERLAP: int
        TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE: int
        TOO_MANY_SCHEDULES_PER_DAY: int
        CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS: int
        DUPLICATE_AD_SCHEDULE: int
        DUPLICATE_KEYWORD: int



from typing import Any

import proto

__protobuf__: Any

class CustomerErrorEnum(proto.Message):
    class CustomerError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        STATUS_CHANGE_DISALLOWED: int
        ACCOUNT_NOT_SET_UP: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1, operations_v1
from google.auth import credentials as ga_credentials
from google.longrunning import operations_pb2

from google.ads.googleads.v8.resources.types import offline_user_data_job
from google.ads.googleads.v8.services.types import offline_user_data_job_service

class OfflineUserDataJobServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: ga_credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def operations_client(self) -> operations_v1.OperationsClient: ...
    @property
    def create_offline_user_data_job(
        self,
    ) -> typing.Callable[
        [offline_user_data_job_service.CreateOfflineUserDataJobRequest],
        offline_user_data_job_service.CreateOfflineUserDataJobResponse,
    ]: ...
    @property
    def get_offline_user_data_job(
        self,
    ) -> typing.Callable[
        [offline_user_data_job_service.GetOfflineUserDataJobRequest],
        offline_user_data_job.OfflineUserDataJob,
    ]: ...
    @property
    def add_offline_user_data_job_operations(
        self,
    ) -> typing.Callable[
        [offline_user_data_job_service.AddOfflineUserDataJobOperationsRequest],
        offline_user_data_job_service.AddOfflineUserDataJobOperationsResponse,
    ]: ...
    @property
    def run_offline_user_data_job(
        self,
    ) -> typing.Callable[
        [offline_user_data_job_service.RunOfflineUserDataJobRequest],
        operations_pb2.Operation,
    ]: ...



from typing import Any

import proto
from google.rpc import status_pb2 as status_pb2

__protobuf__: Any

class GetFeedMappingRequest(proto.Message):
    resource_name: Any

class MutateFeedMappingsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any
    response_content_type: Any

class FeedMappingOperation(proto.Message):
    create: Any
    remove: Any

class MutateFeedMappingsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateFeedMappingResult(proto.Message):
    resource_name: Any
    feed_mapping: Any



from typing import Any

import proto

__protobuf__: Any

class OperatorErrorEnum(proto.Message):
    class OperatorError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        OPERATOR_NOT_SUPPORTED: int



from typing import Any

import proto

__protobuf__: Any

class PolicyViolationErrorEnum(proto.Message):
    class PolicyViolationError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        POLICY_ERROR: int



from typing import Any

import proto

__protobuf__: Any

class CustomAudienceTypeEnum(proto.Message):
    class CustomAudienceType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AUTO: int
        INTEREST: int
        PURCHASE_INTENT: int
        SEARCH: int



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanErrorEnum(proto.Message):
    class KeywordPlanError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BID_MULTIPLIER_OUT_OF_RANGE: int
        BID_TOO_HIGH: int
        BID_TOO_LOW: int
        BID_TOO_MANY_FRACTIONAL_DIGITS: int
        DAILY_BUDGET_TOO_LOW: int
        DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS: int
        INVALID_VALUE: int
        KEYWORD_PLAN_HAS_NO_KEYWORDS: int
        KEYWORD_PLAN_NOT_ENABLED: int
        KEYWORD_PLAN_NOT_FOUND: int
        MISSING_BID: int
        MISSING_FORECAST_PERIOD: int
        INVALID_FORECAST_DATE_RANGE: int
        INVALID_NAME: int



from typing import Any

import proto

__protobuf__: Any

class LegacyAppInstallAdAppStoreEnum(proto.Message):
    class LegacyAppInstallAdAppStore(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        APPLE_APP_STORE: int
        GOOGLE_PLAY: int
        WINDOWS_STORE: int
        WINDOWS_PHONE_STORE: int
        CN_APP_STORE: int



from typing import Any

import proto

__protobuf__: Any

class TimeTypeEnum(proto.Message):
    class TimeType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NOW: int
        FOREVER: int



from .base import (
    BiddingDataExclusionServiceTransport as BiddingDataExclusionServiceTransport,
)
from .grpc import (
    BiddingDataExclusionServiceGrpcTransport as BiddingDataExclusionServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class RecommendationErrorEnum(proto.Message):
    class RecommendationError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BUDGET_AMOUNT_TOO_SMALL: int
        BUDGET_AMOUNT_TOO_LARGE: int
        INVALID_BUDGET_AMOUNT: int
        POLICY_ERROR: int
        INVALID_BID_AMOUNT: int
        ADGROUP_KEYWORD_LIMIT: int
        RECOMMENDATION_ALREADY_APPLIED: int
        RECOMMENDATION_INVALIDATED: int
        TOO_MANY_OPERATIONS: int
        NO_OPERATIONS: int
        DIFFERENT_TYPES_NOT_SUPPORTED: int
        DUPLICATE_RESOURCE_NAME: int
        RECOMMENDATION_ALREADY_DISMISSED: int
        INVALID_APPLY_REQUEST: int



from typing import Any

import proto

from google.ads.googleads.v8.resources.types import payments_account as payments_account

__protobuf__: Any

class ListPaymentsAccountsRequest(proto.Message):
    customer_id: Any

class ListPaymentsAccountsResponse(proto.Message):
    payments_accounts: Any



from typing import Any

import proto

__protobuf__: Any

class SimulationModificationMethodEnum(proto.Message):
    class SimulationModificationMethod(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UNIFORM: int
        DEFAULT: int
        SCALING: int



from typing import Any

import proto

__protobuf__: Any

class CampaignExperimentErrorEnum(proto.Message):
    class CampaignExperimentError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DUPLICATE_NAME: int
        INVALID_TRANSITION: int
        CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET: int
        CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN: int
        CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT: int
        CUSTOMER_CANNOT_CREATE_EXPERIMENT: int
        CAMPAIGN_CANNOT_CREATE_EXPERIMENT: int
        EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP: int
        EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION: int
        CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import user_lists as user_lists
from google.ads.googleads.v8.enums.types import (
    user_list_access_status as user_list_access_status,
    user_list_closing_reason as user_list_closing_reason,
    user_list_membership_status as user_list_membership_status,
    user_list_size_range as user_list_size_range,
    user_list_type as user_list_type,
)

__protobuf__: Any

class UserList(proto.Message):
    resource_name: Any
    id: Any
    read_only: Any
    name: Any
    description: Any
    membership_status: Any
    integration_code: Any
    membership_life_span: Any
    size_for_display: Any
    size_range_for_display: Any
    size_for_search: Any
    size_range_for_search: Any
    type_: Any
    closing_reason: Any
    access_reason: Any
    account_user_list_status: Any
    eligible_for_search: Any
    eligible_for_display: Any
    match_rate_percentage: Any
    crm_based_user_list: Any
    similar_user_list: Any
    rule_based_user_list: Any
    logical_user_list: Any
    basic_user_list: Any



from typing import Union

import grpc

from google.ads.googleads.v7 import GoogleAdsFailure as GoogleAdsFailureV7
from google.ads.googleads.v8 import GoogleAdsFailure as GoogleAdsFailureV8

GoogleAdsFailure = Union[GoogleAdsFailureV7, GoogleAdsFailureV8]

class GoogleAdsException(Exception):
    error: grpc.RpcError = ...
    call: grpc.Call = ...
    failure: GoogleAdsFailure = ...
    request_id: str = ...
    def __init__(
        self,
        error: grpc.RpcError,
        call: grpc.Call,
        failure: GoogleAdsFailure,
        request_id: str,
    ) -> None: ...



from typing import Any

import proto

from google.ads.googleads.v7.common.types import value as value
from google.ads.googleads.v7.enums.types import (
    resource_limit_type as resource_limit_type,
)

__protobuf__: Any

class GoogleAdsFailure(proto.Message):
    errors: Any
    request_id: Any

class GoogleAdsError(proto.Message):
    error_code: Any
    message: Any
    trigger: Any
    location: Any
    details: Any

class ErrorCode(proto.Message):
    request_error: Any
    bidding_strategy_error: Any
    url_field_error: Any
    list_operation_error: Any
    query_error: Any
    mutate_error: Any
    field_mask_error: Any
    authorization_error: Any
    internal_error: Any
    quota_error: Any
    ad_error: Any
    ad_group_error: Any
    campaign_budget_error: Any
    campaign_error: Any
    authentication_error: Any
    ad_group_criterion_error: Any
    ad_customizer_error: Any
    ad_group_ad_error: Any
    ad_sharing_error: Any
    adx_error: Any
    asset_error: Any
    bidding_error: Any
    campaign_criterion_error: Any
    collection_size_error: Any
    country_code_error: Any
    criterion_error: Any
    customer_error: Any
    date_error: Any
    date_range_error: Any
    distinct_error: Any
    feed_attribute_reference_error: Any
    function_error: Any
    function_parsing_error: Any
    id_error: Any
    image_error: Any
    language_code_error: Any
    media_bundle_error: Any
    media_upload_error: Any
    media_file_error: Any
    multiplier_error: Any
    new_resource_creation_error: Any
    not_empty_error: Any
    null_error: Any
    operator_error: Any
    range_error: Any
    recommendation_error: Any
    region_code_error: Any
    setting_error: Any
    string_format_error: Any
    string_length_error: Any
    operation_access_denied_error: Any
    resource_access_denied_error: Any
    resource_count_limit_exceeded_error: Any
    youtube_video_registration_error: Any
    ad_group_bid_modifier_error: Any
    context_error: Any
    field_error: Any
    shared_set_error: Any
    shared_criterion_error: Any
    campaign_shared_set_error: Any
    conversion_action_error: Any
    conversion_adjustment_upload_error: Any
    conversion_custom_variable_error: Any
    conversion_upload_error: Any
    header_error: Any
    database_error: Any
    policy_finding_error: Any
    enum_error: Any
    keyword_plan_error: Any
    keyword_plan_campaign_error: Any
    keyword_plan_campaign_keyword_error: Any
    keyword_plan_ad_group_error: Any
    keyword_plan_ad_group_keyword_error: Any
    keyword_plan_idea_error: Any
    account_budget_proposal_error: Any
    user_list_error: Any
    change_event_error: Any
    change_status_error: Any
    feed_error: Any
    geo_target_constant_suggestion_error: Any
    campaign_draft_error: Any
    feed_item_error: Any
    label_error: Any
    billing_setup_error: Any
    customer_client_link_error: Any
    customer_manager_link_error: Any
    feed_mapping_error: Any
    customer_feed_error: Any
    ad_group_feed_error: Any
    campaign_feed_error: Any
    custom_interest_error: Any
    campaign_experiment_error: Any
    extension_feed_item_error: Any
    ad_parameter_error: Any
    feed_item_validation_error: Any
    extension_setting_error: Any
    feed_item_set_error: Any
    feed_item_set_link_error: Any
    feed_item_target_error: Any
    policy_violation_error: Any
    partial_failure_error: Any
    policy_validation_parameter_error: Any
    size_limit_error: Any
    offline_user_data_job_error: Any
    not_allowlisted_error: Any
    manager_link_error: Any
    currency_code_error: Any
    access_invitation_error: Any
    reach_plan_error: Any
    invoice_error: Any
    payments_account_error: Any
    time_zone_error: Any
    asset_link_error: Any
    user_data_error: Any
    batch_job_error: Any
    account_link_error: Any
    third_party_app_analytics_link_error: Any
    customer_user_access_error: Any
    custom_audience_error: Any

class ErrorLocation(proto.Message):
    class FieldPathElement(proto.Message):
        field_name: Any
        index: Any
    field_path_elements: Any

class ErrorDetails(proto.Message):
    unpublished_error_code: Any
    policy_violation_details: Any
    policy_finding_details: Any
    quota_error_details: Any
    resource_count_details: Any

class PolicyViolationDetails(proto.Message):
    external_policy_description: Any
    key: Any
    external_policy_name: Any
    is_exemptible: Any

class PolicyFindingDetails(proto.Message):
    policy_topic_entries: Any

class QuotaErrorDetails(proto.Message):
    class QuotaRateScope(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ACCOUNT: int
        DEVELOPER: int
    rate_scope: Any
    rate_name: Any
    retry_delay: Any

class ResourceCountDetails(proto.Message):
    enclosing_id: Any
    enclosing_resource: Any
    limit: Any
    limit_type: Any
    existing_count: Any
